from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Microsoft.UI
import win32more.Microsoft.UI.Composition
import win32more.Microsoft.UI.Content
import win32more.Microsoft.UI.Dispatching
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Foundation.Numerics
import win32more.Windows.Graphics
import win32more.Windows.UI.Composition
import win32more.Windows.Win32.System.WinRT
class ContentCoordinateConverter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Content.IContentCoordinateConverter
    _classid_ = 'Microsoft.UI.Content.ContentCoordinateConverter'
    @winrt_mixinmethod
    def ConvertLocalToScreenWithRect(self: win32more.Microsoft.UI.Content.IContentCoordinateConverter, localRect: win32more.Windows.Foundation.Rect) -> win32more.Windows.Graphics.RectInt32: ...
    @winrt_mixinmethod
    def ConvertLocalToScreenWithPoints(self: win32more.Microsoft.UI.Content.IContentCoordinateConverter, localPoints: PassArray[win32more.Windows.Foundation.Point]) -> ReceiveArray[win32more.Windows.Graphics.PointInt32]: ...
    @winrt_mixinmethod
    def ConvertLocalToScreenWithPointsAndRoundingMode(self: win32more.Microsoft.UI.Content.IContentCoordinateConverter, localPoints: PassArray[win32more.Windows.Foundation.Point], roundingMode: win32more.Microsoft.UI.Content.ContentCoordinateRoundingMode) -> ReceiveArray[win32more.Windows.Graphics.PointInt32]: ...
    @winrt_mixinmethod
    def ConvertLocalToScreenWithPoint(self: win32more.Microsoft.UI.Content.IContentCoordinateConverter, localPoint: win32more.Windows.Foundation.Point) -> win32more.Windows.Graphics.PointInt32: ...
    @winrt_mixinmethod
    def ConvertScreenToLocalWithPoint(self: win32more.Microsoft.UI.Content.IContentCoordinateConverter, screenPoint: win32more.Windows.Graphics.PointInt32) -> win32more.Windows.Foundation.Point: ...
    @winrt_mixinmethod
    def ConvertScreenToLocalWithPoints(self: win32more.Microsoft.UI.Content.IContentCoordinateConverter, screenPoints: PassArray[win32more.Windows.Graphics.PointInt32]) -> ReceiveArray[win32more.Windows.Foundation.Point]: ...
    @winrt_mixinmethod
    def ConvertScreenToLocalWithRect(self: win32more.Microsoft.UI.Content.IContentCoordinateConverter, screenRect: win32more.Windows.Graphics.RectInt32) -> win32more.Windows.Foundation.Rect: ...
    @winrt_classmethod
    def CreateForWindowId(cls: win32more.Microsoft.UI.Content.IContentCoordinateConverterStatics, windowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.UI.Content.ContentCoordinateConverter: ...
class ContentCoordinateRoundingMode(Enum, Int32):
    Auto = 0
    Floor = 1
    Round = 2
    Ceiling = 3
class ContentDeferral(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Content.IContentDeferral
    _classid_ = 'Microsoft.UI.Content.ContentDeferral'
    @winrt_mixinmethod
    def Complete(self: win32more.Microsoft.UI.Content.IContentDeferral) -> Void: ...
class ContentEnvironmentSettingChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Content.IContentEnvironmentSettingChangedEventArgs
    _classid_ = 'Microsoft.UI.Content.ContentEnvironmentSettingChangedEventArgs'
    @winrt_mixinmethod
    def get_SettingName(self: win32more.Microsoft.UI.Content.IContentEnvironmentSettingChangedEventArgs) -> WinRT_String: ...
    SettingName = property(get_SettingName, None)
class ContentEnvironmentStateChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Content.IContentEnvironmentStateChangedEventArgs
    _classid_ = 'Microsoft.UI.Content.ContentEnvironmentStateChangedEventArgs'
    @winrt_mixinmethod
    def get_DidAppWindowIdChange(self: win32more.Microsoft.UI.Content.IContentEnvironmentStateChangedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_DidDisplayIdChange(self: win32more.Microsoft.UI.Content.IContentEnvironmentStateChangedEventArgs) -> Boolean: ...
    DidAppWindowIdChange = property(get_DidAppWindowIdChange, None)
    DidDisplayIdChange = property(get_DidDisplayIdChange, None)
class ContentIsland(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Microsoft.UI.Content.IContentIsland
    _classid_ = 'Microsoft.UI.Content.ContentIsland'
    @winrt_mixinmethod
    def put_IsIslandVisible(self: win32more.Microsoft.UI.Content.IContentIsland, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_AppData(self: win32more.Microsoft.UI.Content.IContentIsland) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_AppData(self: win32more.Microsoft.UI.Content.IContentIsland, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_CoordinateConverter(self: win32more.Microsoft.UI.Content.IContentIsland) -> win32more.Microsoft.UI.Content.ContentCoordinateConverter: ...
    @winrt_mixinmethod
    def get_CustomProperties(self: win32more.Microsoft.UI.Content.IContentIsland) -> win32more.Windows.Foundation.Collections.IPropertySet: ...
    @winrt_mixinmethod
    def get_DispatcherQueue(self: win32more.Microsoft.UI.Content.IContentIsland) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
    @winrt_mixinmethod
    def get_Environment(self: win32more.Microsoft.UI.Content.IContentIsland) -> win32more.Microsoft.UI.Content.ContentIslandEnvironment: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Microsoft.UI.Content.IContentIsland) -> UInt64: ...
    @winrt_mixinmethod
    def get_IsConnected(self: win32more.Microsoft.UI.Content.IContentIsland) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsHitTestVisibleWhenTransparent(self: win32more.Microsoft.UI.Content.IContentIsland) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsHitTestVisibleWhenTransparent(self: win32more.Microsoft.UI.Content.IContentIsland, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsIslandEnabled(self: win32more.Microsoft.UI.Content.IContentIsland) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsIslandEnabled(self: win32more.Microsoft.UI.Content.IContentIsland, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsIslandVisible(self: win32more.Microsoft.UI.Content.IContentIsland) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsClosed(self: win32more.Microsoft.UI.IClosableNotifier) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsSiteEnabled(self: win32more.Microsoft.UI.Content.IContentIsland) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsSiteVisible(self: win32more.Microsoft.UI.Content.IContentIsland) -> Boolean: ...
    @winrt_mixinmethod
    def get_LayoutDirection(self: win32more.Microsoft.UI.Content.IContentIsland) -> win32more.Microsoft.UI.Content.ContentLayoutDirection: ...
    @winrt_mixinmethod
    def get_RasterizationScale(self: win32more.Microsoft.UI.Content.IContentIsland) -> Single: ...
    @winrt_mixinmethod
    def GetAutomationHostProvider(self: win32more.Microsoft.UI.Content.IContentIsland) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def GetStateChangeDeferral(self: win32more.Microsoft.UI.Content.IContentIsland) -> win32more.Microsoft.UI.Content.ContentDeferral: ...
    @winrt_mixinmethod
    def RequestSize(self: win32more.Microsoft.UI.Content.IContentIsland, size: win32more.Windows.Foundation.Numerics.Vector2) -> Void: ...
    @winrt_mixinmethod
    def add_AutomationProviderRequested(self: win32more.Microsoft.UI.Content.IContentIsland, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Content.ContentIsland, win32more.Microsoft.UI.Content.ContentIslandAutomationProviderRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_AutomationProviderRequested(self: win32more.Microsoft.UI.Content.IContentIsland, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_StateChanged(self: win32more.Microsoft.UI.Content.IContentIsland, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Content.ContentIsland, win32more.Microsoft.UI.Content.ContentIslandStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_StateChanged(self: win32more.Microsoft.UI.Content.IContentIsland, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_mixinmethod
    def get_ActualSize(self: win32more.Microsoft.UI.Content.IContentIsland) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_mixinmethod
    def add_Closed(self: win32more.Microsoft.UI.IClosableNotifier, handler: win32more.Microsoft.UI.ClosableNotifierHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closed(self: win32more.Microsoft.UI.IClosableNotifier, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_FrameworkClosed(self: win32more.Microsoft.UI.IClosableNotifier, handler: win32more.Microsoft.UI.ClosableNotifierHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FrameworkClosed(self: win32more.Microsoft.UI.IClosableNotifier, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_SystemBackdrop(self: win32more.Microsoft.UI.Composition.ICompositionSupportsSystemBackdrop) -> win32more.Windows.UI.Composition.CompositionBrush: ...
    @winrt_mixinmethod
    def put_SystemBackdrop(self: win32more.Microsoft.UI.Composition.ICompositionSupportsSystemBackdrop, value: win32more.Windows.UI.Composition.CompositionBrush) -> Void: ...
    @winrt_classmethod
    def Create(cls: win32more.Microsoft.UI.Content.IContentIslandStatics, Root: win32more.Microsoft.UI.Composition.Visual) -> win32more.Microsoft.UI.Content.ContentIsland: ...
    @winrt_classmethod
    def FindAllForCompositor(cls: win32more.Microsoft.UI.Content.IContentIslandStatics, compositor: win32more.Microsoft.UI.Composition.Compositor) -> ReceiveArray[win32more.Microsoft.UI.Content.ContentIsland]: ...
    @winrt_classmethod
    def FindAllForCurrentThread(cls: win32more.Microsoft.UI.Content.IContentIslandStatics) -> ReceiveArray[win32more.Microsoft.UI.Content.ContentIsland]: ...
    @winrt_classmethod
    def GetByVisual(cls: win32more.Microsoft.UI.Content.IContentIslandStatics, child: win32more.Microsoft.UI.Composition.Visual) -> win32more.Microsoft.UI.Content.ContentIsland: ...
    @winrt_classmethod
    def GetFromId(cls: win32more.Microsoft.UI.Content.IContentIslandStatics, id: UInt64) -> win32more.Microsoft.UI.Content.ContentIsland: ...
    ActualSize = property(get_ActualSize, None)
    AppData = property(get_AppData, put_AppData)
    CoordinateConverter = property(get_CoordinateConverter, None)
    CustomProperties = property(get_CustomProperties, None)
    DispatcherQueue = property(get_DispatcherQueue, None)
    Environment = property(get_Environment, None)
    Id = property(get_Id, None)
    IsClosed = property(get_IsClosed, None)
    IsConnected = property(get_IsConnected, None)
    IsHitTestVisibleWhenTransparent = property(get_IsHitTestVisibleWhenTransparent, put_IsHitTestVisibleWhenTransparent)
    IsIslandEnabled = property(get_IsIslandEnabled, put_IsIslandEnabled)
    IsIslandVisible = property(get_IsIslandVisible, put_IsIslandVisible)
    IsSiteEnabled = property(get_IsSiteEnabled, None)
    IsSiteVisible = property(get_IsSiteVisible, None)
    LayoutDirection = property(get_LayoutDirection, None)
    RasterizationScale = property(get_RasterizationScale, None)
    SystemBackdrop = property(get_SystemBackdrop, put_SystemBackdrop)
    AutomationProviderRequested = event()
    StateChanged = event()
    Closed = event()
    FrameworkClosed = event()
class ContentIslandAutomationProviderRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Content.IContentIslandAutomationProviderRequestedEventArgs
    _classid_ = 'Microsoft.UI.Content.ContentIslandAutomationProviderRequestedEventArgs'
    @winrt_mixinmethod
    def get_Handled(self: win32more.Microsoft.UI.Content.IContentIslandAutomationProviderRequestedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_AutomationProvider(self: win32more.Microsoft.UI.Content.IContentIslandAutomationProviderRequestedEventArgs, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_AutomationProvider(self: win32more.Microsoft.UI.Content.IContentIslandAutomationProviderRequestedEventArgs) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Microsoft.UI.Content.IContentIslandAutomationProviderRequestedEventArgs, value: Boolean) -> Void: ...
    AutomationProvider = property(get_AutomationProvider, put_AutomationProvider)
    Handled = property(get_Handled, put_Handled)
class ContentIslandEnvironment(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Content.IContentIslandEnvironment
    _classid_ = 'Microsoft.UI.Content.ContentIslandEnvironment'
    @winrt_mixinmethod
    def get_DisplayId(self: win32more.Microsoft.UI.Content.IContentIslandEnvironment) -> win32more.Microsoft.UI.DisplayId: ...
    @winrt_mixinmethod
    def get_AppWindowId(self: win32more.Microsoft.UI.Content.IContentIslandEnvironment) -> win32more.Microsoft.UI.WindowId: ...
    @winrt_mixinmethod
    def add_SettingChanged(self: win32more.Microsoft.UI.Content.IContentIslandEnvironment, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Content.ContentIslandEnvironment, win32more.Microsoft.UI.Content.ContentEnvironmentSettingChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SettingChanged(self: win32more.Microsoft.UI.Content.IContentIslandEnvironment, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_StateChanged(self: win32more.Microsoft.UI.Content.IContentIslandEnvironment, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Content.ContentIslandEnvironment, win32more.Microsoft.UI.Content.ContentEnvironmentStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_StateChanged(self: win32more.Microsoft.UI.Content.IContentIslandEnvironment, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AppWindowId = property(get_AppWindowId, None)
    DisplayId = property(get_DisplayId, None)
    SettingChanged = event()
    StateChanged = event()
class ContentIslandStateChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Content.IContentIslandStateChangedEventArgs
    _classid_ = 'Microsoft.UI.Content.ContentIslandStateChangedEventArgs'
    @winrt_mixinmethod
    def get_DidSiteEnabledChange(self: win32more.Microsoft.UI.Content.IContentIslandStateChangedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_DidActualSizeChange(self: win32more.Microsoft.UI.Content.IContentIslandStateChangedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_DidSiteVisibleChange(self: win32more.Microsoft.UI.Content.IContentIslandStateChangedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_DidLayoutDirectionChange(self: win32more.Microsoft.UI.Content.IContentIslandStateChangedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_DidRasterizationScaleChange(self: win32more.Microsoft.UI.Content.IContentIslandStateChangedEventArgs) -> Boolean: ...
    DidActualSizeChange = property(get_DidActualSizeChange, None)
    DidLayoutDirectionChange = property(get_DidLayoutDirectionChange, None)
    DidRasterizationScaleChange = property(get_DidRasterizationScaleChange, None)
    DidSiteEnabledChange = property(get_DidSiteEnabledChange, None)
    DidSiteVisibleChange = property(get_DidSiteVisibleChange, None)
class ContentLayoutDirection(Enum, Int32):
    LeftToRight = 0
    RightToLeft = 1
class ContentSite(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Microsoft.UI.Content.IContentSite
    _classid_ = 'Microsoft.UI.Content.ContentSite'
    @winrt_mixinmethod
    def get_RasterizationScale(self: win32more.Microsoft.UI.Content.IContentSite) -> Single: ...
    @winrt_mixinmethod
    def put_ActualSize(self: win32more.Microsoft.UI.Content.IContentSite, value: win32more.Windows.Foundation.Numerics.Vector2) -> Void: ...
    @winrt_mixinmethod
    def get_ClientSize(self: win32more.Microsoft.UI.Content.IContentSite) -> win32more.Windows.Graphics.SizeInt32: ...
    @winrt_mixinmethod
    def put_ClientSize(self: win32more.Microsoft.UI.Content.IContentSite, value: win32more.Windows.Graphics.SizeInt32) -> Void: ...
    @winrt_mixinmethod
    def get_CoordinateConverter(self: win32more.Microsoft.UI.Content.IContentSite) -> win32more.Microsoft.UI.Content.ContentCoordinateConverter: ...
    @winrt_mixinmethod
    def get_DispatcherQueue(self: win32more.Microsoft.UI.Content.IContentSite) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
    @winrt_mixinmethod
    def get_Environment(self: win32more.Microsoft.UI.Content.IContentSite) -> win32more.Microsoft.UI.Content.ContentSiteEnvironment: ...
    @winrt_mixinmethod
    def get_IsConnected(self: win32more.Microsoft.UI.Content.IContentSite) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsSiteEnabled(self: win32more.Microsoft.UI.Content.IContentSite) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSiteEnabled(self: win32more.Microsoft.UI.Content.IContentSite, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsSiteVisible(self: win32more.Microsoft.UI.Content.IContentSite) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSiteVisible(self: win32more.Microsoft.UI.Content.IContentSite, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_LayoutDirection(self: win32more.Microsoft.UI.Content.IContentSite) -> win32more.Microsoft.UI.Content.ContentLayoutDirection: ...
    @winrt_mixinmethod
    def put_LayoutDirection(self: win32more.Microsoft.UI.Content.IContentSite, value: win32more.Microsoft.UI.Content.ContentLayoutDirection) -> Void: ...
    @winrt_mixinmethod
    def get_OverrideScale(self: win32more.Microsoft.UI.Content.IContentSite) -> Single: ...
    @winrt_mixinmethod
    def put_OverrideScale(self: win32more.Microsoft.UI.Content.IContentSite, value: Single) -> Void: ...
    @winrt_mixinmethod
    def get_ParentScale(self: win32more.Microsoft.UI.Content.IContentSite) -> Single: ...
    @winrt_mixinmethod
    def put_ParentScale(self: win32more.Microsoft.UI.Content.IContentSite, value: Single) -> Void: ...
    @winrt_mixinmethod
    def get_View(self: win32more.Microsoft.UI.Content.IContentSite) -> win32more.Microsoft.UI.Content.ContentSiteView: ...
    @winrt_mixinmethod
    def get_RequestedSize(self: win32more.Microsoft.UI.Content.IContentSite) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_mixinmethod
    def get_ShouldApplyRasterizationScale(self: win32more.Microsoft.UI.Content.IContentSite) -> Boolean: ...
    @winrt_mixinmethod
    def put_ShouldApplyRasterizationScale(self: win32more.Microsoft.UI.Content.IContentSite, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ActualSize(self: win32more.Microsoft.UI.Content.IContentSite) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_mixinmethod
    def GetIslandStateChangeDeferral(self: win32more.Microsoft.UI.Content.IContentSite) -> win32more.Microsoft.UI.Content.ContentDeferral: ...
    @winrt_mixinmethod
    def add_RequestedStateChanged(self: win32more.Microsoft.UI.Content.IContentSite, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Content.ContentSite, win32more.Microsoft.UI.Content.ContentSiteRequestedStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_RequestedStateChanged(self: win32more.Microsoft.UI.Content.IContentSite, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_mixinmethod
    def get_IsClosed(self: win32more.Microsoft.UI.IClosableNotifier) -> Boolean: ...
    @winrt_mixinmethod
    def add_Closed(self: win32more.Microsoft.UI.IClosableNotifier, handler: win32more.Microsoft.UI.ClosableNotifierHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closed(self: win32more.Microsoft.UI.IClosableNotifier, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_FrameworkClosed(self: win32more.Microsoft.UI.IClosableNotifier, handler: win32more.Microsoft.UI.ClosableNotifierHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FrameworkClosed(self: win32more.Microsoft.UI.IClosableNotifier, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ActualSize = property(get_ActualSize, put_ActualSize)
    ClientSize = property(get_ClientSize, put_ClientSize)
    CoordinateConverter = property(get_CoordinateConverter, None)
    DispatcherQueue = property(get_DispatcherQueue, None)
    Environment = property(get_Environment, None)
    IsClosed = property(get_IsClosed, None)
    IsConnected = property(get_IsConnected, None)
    IsSiteEnabled = property(get_IsSiteEnabled, put_IsSiteEnabled)
    IsSiteVisible = property(get_IsSiteVisible, put_IsSiteVisible)
    LayoutDirection = property(get_LayoutDirection, put_LayoutDirection)
    OverrideScale = property(get_OverrideScale, put_OverrideScale)
    ParentScale = property(get_ParentScale, put_ParentScale)
    RasterizationScale = property(get_RasterizationScale, None)
    RequestedSize = property(get_RequestedSize, None)
    ShouldApplyRasterizationScale = property(get_ShouldApplyRasterizationScale, put_ShouldApplyRasterizationScale)
    View = property(get_View, None)
    RequestedStateChanged = event()
    Closed = event()
    FrameworkClosed = event()
class ContentSiteEnvironment(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Content.IContentSiteEnvironment
    _classid_ = 'Microsoft.UI.Content.ContentSiteEnvironment'
    @winrt_mixinmethod
    def get_AppWindowId(self: win32more.Microsoft.UI.Content.IContentSiteEnvironment) -> win32more.Microsoft.UI.WindowId: ...
    @winrt_mixinmethod
    def put_AppWindowId(self: win32more.Microsoft.UI.Content.IContentSiteEnvironment, value: win32more.Microsoft.UI.WindowId) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayId(self: win32more.Microsoft.UI.Content.IContentSiteEnvironment) -> win32more.Microsoft.UI.DisplayId: ...
    @winrt_mixinmethod
    def put_DisplayId(self: win32more.Microsoft.UI.Content.IContentSiteEnvironment, value: win32more.Microsoft.UI.DisplayId) -> Void: ...
    @winrt_mixinmethod
    def get_View(self: win32more.Microsoft.UI.Content.IContentSiteEnvironment) -> win32more.Microsoft.UI.Content.ContentSiteEnvironmentView: ...
    @winrt_mixinmethod
    def NotifySettingChanged(self: win32more.Microsoft.UI.Content.IContentSiteEnvironment, setting: WinRT_String) -> Void: ...
    AppWindowId = property(get_AppWindowId, put_AppWindowId)
    DisplayId = property(get_DisplayId, put_DisplayId)
    View = property(get_View, None)
class ContentSiteEnvironmentView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Content.IContentSiteEnvironmentView
    _classid_ = 'Microsoft.UI.Content.ContentSiteEnvironmentView'
    @winrt_mixinmethod
    def get_AppWindowId(self: win32more.Microsoft.UI.Content.IContentSiteEnvironmentView) -> win32more.Microsoft.UI.WindowId: ...
    @winrt_mixinmethod
    def get_DisplayId(self: win32more.Microsoft.UI.Content.IContentSiteEnvironmentView) -> win32more.Microsoft.UI.DisplayId: ...
    AppWindowId = property(get_AppWindowId, None)
    DisplayId = property(get_DisplayId, None)
class ContentSiteRequestedStateChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Content.IContentSiteRequestedStateChangedEventArgs
    _classid_ = 'Microsoft.UI.Content.ContentSiteRequestedStateChangedEventArgs'
    @winrt_mixinmethod
    def get_DidRequestedSizeChange(self: win32more.Microsoft.UI.Content.IContentSiteRequestedStateChangedEventArgs) -> Boolean: ...
    DidRequestedSizeChange = property(get_DidRequestedSizeChange, None)
class ContentSiteView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Content.IContentSiteView
    _classid_ = 'Microsoft.UI.Content.ContentSiteView'
    @winrt_mixinmethod
    def get_ActualSize(self: win32more.Microsoft.UI.Content.IContentSiteView) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_mixinmethod
    def get_ClientSize(self: win32more.Microsoft.UI.Content.IContentSiteView) -> win32more.Windows.Graphics.SizeInt32: ...
    @winrt_mixinmethod
    def get_CoordinateConverter(self: win32more.Microsoft.UI.Content.IContentSiteView) -> win32more.Microsoft.UI.Content.ContentCoordinateConverter: ...
    @winrt_mixinmethod
    def get_DispatcherQueue(self: win32more.Microsoft.UI.Content.IContentSiteView) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
    @winrt_mixinmethod
    def get_EnvironmentView(self: win32more.Microsoft.UI.Content.IContentSiteView) -> win32more.Microsoft.UI.Content.ContentSiteEnvironmentView: ...
    @winrt_mixinmethod
    def get_IsConnected(self: win32more.Microsoft.UI.Content.IContentSiteView) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsSiteEnabled(self: win32more.Microsoft.UI.Content.IContentSiteView) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsSiteVisible(self: win32more.Microsoft.UI.Content.IContentSiteView) -> Boolean: ...
    @winrt_mixinmethod
    def get_LayoutDirection(self: win32more.Microsoft.UI.Content.IContentSiteView) -> win32more.Microsoft.UI.Content.ContentLayoutDirection: ...
    @winrt_mixinmethod
    def get_OverrideScale(self: win32more.Microsoft.UI.Content.IContentSiteView) -> Single: ...
    @winrt_mixinmethod
    def get_ParentScale(self: win32more.Microsoft.UI.Content.IContentSiteView) -> Single: ...
    @winrt_mixinmethod
    def get_RasterizationScale(self: win32more.Microsoft.UI.Content.IContentSiteView) -> Single: ...
    @winrt_mixinmethod
    def get_RequestedSize(self: win32more.Microsoft.UI.Content.IContentSiteView) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_mixinmethod
    def get_ShouldApplyRasterizationScale(self: win32more.Microsoft.UI.Content.IContentSiteView) -> Boolean: ...
    ActualSize = property(get_ActualSize, None)
    ClientSize = property(get_ClientSize, None)
    CoordinateConverter = property(get_CoordinateConverter, None)
    DispatcherQueue = property(get_DispatcherQueue, None)
    EnvironmentView = property(get_EnvironmentView, None)
    IsConnected = property(get_IsConnected, None)
    IsSiteEnabled = property(get_IsSiteEnabled, None)
    IsSiteVisible = property(get_IsSiteVisible, None)
    LayoutDirection = property(get_LayoutDirection, None)
    OverrideScale = property(get_OverrideScale, None)
    ParentScale = property(get_ParentScale, None)
    RasterizationScale = property(get_RasterizationScale, None)
    RequestedSize = property(get_RequestedSize, None)
    ShouldApplyRasterizationScale = property(get_ShouldApplyRasterizationScale, None)
class ContentSizePolicy(Enum, Int32):
    None_ = 0
    ResizeContentToParentWindow = 1
    ResizeParentWindowToContent = 2
class DesktopChildSiteBridge(ComPtr):
    extends: win32more.Microsoft.UI.Content.DesktopSiteBridge
    default_interface: win32more.Microsoft.UI.Content.IDesktopChildSiteBridge
    _classid_ = 'Microsoft.UI.Content.DesktopChildSiteBridge'
    @winrt_mixinmethod
    def get_ResizePolicy(self: win32more.Microsoft.UI.Content.IDesktopChildSiteBridge) -> win32more.Microsoft.UI.Content.ContentSizePolicy: ...
    @winrt_mixinmethod
    def put_ResizePolicy(self: win32more.Microsoft.UI.Content.IDesktopChildSiteBridge, value: win32more.Microsoft.UI.Content.ContentSizePolicy) -> Void: ...
    @winrt_mixinmethod
    def get_SiteView(self: win32more.Microsoft.UI.Content.IDesktopChildSiteBridge) -> win32more.Microsoft.UI.Content.ContentSiteView: ...
    @winrt_classmethod
    def Create(cls: win32more.Microsoft.UI.Content.IDesktopChildSiteBridgeStatics, compositor: win32more.Microsoft.UI.Composition.Compositor, parentWindowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.UI.Content.DesktopChildSiteBridge: ...
    ResizePolicy = property(get_ResizePolicy, put_ResizePolicy)
    SiteView = property(get_SiteView, None)
class DesktopSiteBridge(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Microsoft.UI.Content.IDesktopSiteBridge
    _classid_ = 'Microsoft.UI.Content.DesktopSiteBridge'
    @winrt_mixinmethod
    def Show(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge) -> Void: ...
    @winrt_mixinmethod
    def get_LayoutDirectionOverride(self: win32more.Microsoft.UI.Content.IContentSiteBridge) -> win32more.Windows.Foundation.IReference[win32more.Microsoft.UI.Content.ContentLayoutDirection]: ...
    @winrt_mixinmethod
    def put_LayoutDirectionOverride(self: win32more.Microsoft.UI.Content.IContentSiteBridge, value: win32more.Windows.Foundation.IReference[win32more.Microsoft.UI.Content.ContentLayoutDirection]) -> Void: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_mixinmethod
    def get_IsVisible(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsEnabled(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge) -> Boolean: ...
    @winrt_mixinmethod
    def Connect(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge, content: win32more.Microsoft.UI.Content.ContentIsland) -> Void: ...
    @winrt_mixinmethod
    def Disable(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge) -> Void: ...
    @winrt_mixinmethod
    def Enable(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge) -> Void: ...
    @winrt_mixinmethod
    def Hide(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge) -> Void: ...
    @winrt_mixinmethod
    def MoveAndResize(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge, rect: win32more.Windows.Graphics.RectInt32) -> Void: ...
    @winrt_mixinmethod
    def MoveInZOrderAtBottom(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge) -> Void: ...
    @winrt_mixinmethod
    def MoveInZOrderAtTop(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge) -> Void: ...
    @winrt_mixinmethod
    def MoveInZOrderBelow(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge, windowId: win32more.Microsoft.UI.WindowId) -> Void: ...
    @winrt_mixinmethod
    def get_IsClosed(self: win32more.Microsoft.UI.IClosableNotifier) -> Boolean: ...
    @winrt_mixinmethod
    def add_Closed(self: win32more.Microsoft.UI.IClosableNotifier, handler: win32more.Microsoft.UI.ClosableNotifierHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closed(self: win32more.Microsoft.UI.IClosableNotifier, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_FrameworkClosed(self: win32more.Microsoft.UI.IClosableNotifier, handler: win32more.Microsoft.UI.ClosableNotifierHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FrameworkClosed(self: win32more.Microsoft.UI.IClosableNotifier, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_DispatcherQueue(self: win32more.Microsoft.UI.Content.IContentSiteBridge) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
    @winrt_mixinmethod
    def get_WindowId(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge) -> win32more.Microsoft.UI.WindowId: ...
    @winrt_mixinmethod
    def get_OverrideScale(self: win32more.Microsoft.UI.Content.IContentSiteBridge) -> Single: ...
    @winrt_mixinmethod
    def put_OverrideScale(self: win32more.Microsoft.UI.Content.IContentSiteBridge, value: Single) -> Void: ...
    @winrt_classmethod
    def IsSupported(cls: win32more.Microsoft.UI.Content.IDesktopSiteBridgeStatics) -> Boolean: ...
    DispatcherQueue = property(get_DispatcherQueue, None)
    IsClosed = property(get_IsClosed, None)
    IsEnabled = property(get_IsEnabled, None)
    IsVisible = property(get_IsVisible, None)
    LayoutDirectionOverride = property(get_LayoutDirectionOverride, put_LayoutDirectionOverride)
    OverrideScale = property(get_OverrideScale, put_OverrideScale)
    WindowId = property(get_WindowId, None)
    Closed = event()
    FrameworkClosed = event()
class IContentCoordinateConverter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentCoordinateConverter'
    _iid_ = Guid('{10a11230-5eb4-5840-a346-570f4a49040f}')
    @winrt_commethod(6)
    def ConvertLocalToScreenWithPoint(self, localPoint: win32more.Windows.Foundation.Point) -> win32more.Windows.Graphics.PointInt32: ...
    @winrt_commethod(7)
    def ConvertLocalToScreenWithPoints(self, localPoints: PassArray[win32more.Windows.Foundation.Point]) -> ReceiveArray[win32more.Windows.Graphics.PointInt32]: ...
    @winrt_commethod(8)
    def ConvertLocalToScreenWithPointsAndRoundingMode(self, localPoints: PassArray[win32more.Windows.Foundation.Point], roundingMode: win32more.Microsoft.UI.Content.ContentCoordinateRoundingMode) -> ReceiveArray[win32more.Windows.Graphics.PointInt32]: ...
    @winrt_commethod(9)
    def ConvertLocalToScreenWithRect(self, localRect: win32more.Windows.Foundation.Rect) -> win32more.Windows.Graphics.RectInt32: ...
    @winrt_commethod(10)
    def ConvertScreenToLocalWithPoint(self, screenPoint: win32more.Windows.Graphics.PointInt32) -> win32more.Windows.Foundation.Point: ...
    @winrt_commethod(11)
    def ConvertScreenToLocalWithPoints(self, screenPoints: PassArray[win32more.Windows.Graphics.PointInt32]) -> ReceiveArray[win32more.Windows.Foundation.Point]: ...
    @winrt_commethod(12)
    def ConvertScreenToLocalWithRect(self, screenRect: win32more.Windows.Graphics.RectInt32) -> win32more.Windows.Foundation.Rect: ...
class IContentCoordinateConverterFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentCoordinateConverterFactory'
    _iid_ = Guid('{a4b216ee-0e26-56bd-9209-a75cf9d80f27}')
class IContentCoordinateConverterStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentCoordinateConverterStatics'
    _iid_ = Guid('{f56374ce-b6df-5b42-a58f-4e3bb039e3a9}')
    @winrt_commethod(6)
    def CreateForWindowId(self, windowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.UI.Content.ContentCoordinateConverter: ...
class IContentDeferral(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentDeferral'
    _iid_ = Guid('{470529f5-cd93-599b-968e-f8a689bc3a07}')
    @winrt_commethod(6)
    def Complete(self) -> Void: ...
class IContentEnvironmentSettingChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentEnvironmentSettingChangedEventArgs'
    _iid_ = Guid('{76478051-fc80-5eec-a3f3-62606abe06b7}')
    @winrt_commethod(6)
    def get_SettingName(self) -> WinRT_String: ...
    SettingName = property(get_SettingName, None)
class IContentEnvironmentStateChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentEnvironmentStateChangedEventArgs'
    _iid_ = Guid('{8970fa4f-10ba-5f67-970b-8c72bc009b67}')
    @winrt_commethod(6)
    def get_DidAppWindowIdChange(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_DidDisplayIdChange(self) -> Boolean: ...
    DidAppWindowIdChange = property(get_DidAppWindowIdChange, None)
    DidDisplayIdChange = property(get_DidDisplayIdChange, None)
class IContentIsland(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentIsland'
    _iid_ = Guid('{5b2504ba-361c-50aa-bd6e-4122c6d93889}')
    @winrt_commethod(6)
    def get_ActualSize(self) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_commethod(7)
    def get_AppData(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(8)
    def put_AppData(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(9)
    def get_CoordinateConverter(self) -> win32more.Microsoft.UI.Content.ContentCoordinateConverter: ...
    @winrt_commethod(10)
    def get_CustomProperties(self) -> win32more.Windows.Foundation.Collections.IPropertySet: ...
    @winrt_commethod(11)
    def get_DispatcherQueue(self) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
    @winrt_commethod(12)
    def get_Environment(self) -> win32more.Microsoft.UI.Content.ContentIslandEnvironment: ...
    @winrt_commethod(13)
    def get_Id(self) -> UInt64: ...
    @winrt_commethod(14)
    def get_IsConnected(self) -> Boolean: ...
    @winrt_commethod(15)
    def get_IsHitTestVisibleWhenTransparent(self) -> Boolean: ...
    @winrt_commethod(16)
    def put_IsHitTestVisibleWhenTransparent(self, value: Boolean) -> Void: ...
    @winrt_commethod(17)
    def get_IsIslandEnabled(self) -> Boolean: ...
    @winrt_commethod(18)
    def put_IsIslandEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(19)
    def get_IsIslandVisible(self) -> Boolean: ...
    @winrt_commethod(20)
    def put_IsIslandVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(21)
    def get_IsSiteEnabled(self) -> Boolean: ...
    @winrt_commethod(22)
    def get_IsSiteVisible(self) -> Boolean: ...
    @winrt_commethod(23)
    def get_LayoutDirection(self) -> win32more.Microsoft.UI.Content.ContentLayoutDirection: ...
    @winrt_commethod(24)
    def get_RasterizationScale(self) -> Single: ...
    @winrt_commethod(25)
    def GetAutomationHostProvider(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(26)
    def GetStateChangeDeferral(self) -> win32more.Microsoft.UI.Content.ContentDeferral: ...
    @winrt_commethod(27)
    def RequestSize(self, size: win32more.Windows.Foundation.Numerics.Vector2) -> Void: ...
    @winrt_commethod(28)
    def add_AutomationProviderRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Content.ContentIsland, win32more.Microsoft.UI.Content.ContentIslandAutomationProviderRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(29)
    def remove_AutomationProviderRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(30)
    def add_StateChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Content.ContentIsland, win32more.Microsoft.UI.Content.ContentIslandStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(31)
    def remove_StateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ActualSize = property(get_ActualSize, None)
    AppData = property(get_AppData, put_AppData)
    CoordinateConverter = property(get_CoordinateConverter, None)
    CustomProperties = property(get_CustomProperties, None)
    DispatcherQueue = property(get_DispatcherQueue, None)
    Environment = property(get_Environment, None)
    Id = property(get_Id, None)
    IsConnected = property(get_IsConnected, None)
    IsHitTestVisibleWhenTransparent = property(get_IsHitTestVisibleWhenTransparent, put_IsHitTestVisibleWhenTransparent)
    IsIslandEnabled = property(get_IsIslandEnabled, put_IsIslandEnabled)
    IsIslandVisible = property(get_IsIslandVisible, put_IsIslandVisible)
    IsSiteEnabled = property(get_IsSiteEnabled, None)
    IsSiteVisible = property(get_IsSiteVisible, None)
    LayoutDirection = property(get_LayoutDirection, None)
    RasterizationScale = property(get_RasterizationScale, None)
    AutomationProviderRequested = event()
    StateChanged = event()
class IContentIslandAutomationProviderRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentIslandAutomationProviderRequestedEventArgs'
    _iid_ = Guid('{9fe24bed-2b9c-5137-887f-403c94841824}')
    @winrt_commethod(6)
    def get_AutomationProvider(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_AutomationProvider(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_Handled(self, value: Boolean) -> Void: ...
    AutomationProvider = property(get_AutomationProvider, put_AutomationProvider)
    Handled = property(get_Handled, put_Handled)
class IContentIslandEnvironment(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentIslandEnvironment'
    _iid_ = Guid('{c334236d-da88-566d-811d-74aef2eba978}')
    @winrt_commethod(6)
    def get_AppWindowId(self) -> win32more.Microsoft.UI.WindowId: ...
    @winrt_commethod(7)
    def get_DisplayId(self) -> win32more.Microsoft.UI.DisplayId: ...
    @winrt_commethod(8)
    def add_SettingChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Content.ContentIslandEnvironment, win32more.Microsoft.UI.Content.ContentEnvironmentSettingChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_SettingChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def add_StateChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Content.ContentIslandEnvironment, win32more.Microsoft.UI.Content.ContentEnvironmentStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_StateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AppWindowId = property(get_AppWindowId, None)
    DisplayId = property(get_DisplayId, None)
    SettingChanged = event()
    StateChanged = event()
class IContentIslandEnvironmentFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentIslandEnvironmentFactory'
    _iid_ = Guid('{47a782d6-b177-5c1e-bf87-90437dd809d0}')
class IContentIslandFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentIslandFactory'
    _iid_ = Guid('{82383f52-e81a-5ec9-a954-bac8a931ba7d}')
class IContentIslandStateChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentIslandStateChangedEventArgs'
    _iid_ = Guid('{c828eeb2-0c62-5b40-9d48-77c06083c278}')
    @winrt_commethod(6)
    def get_DidActualSizeChange(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_DidSiteEnabledChange(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_DidSiteVisibleChange(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_DidLayoutDirectionChange(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_DidRasterizationScaleChange(self) -> Boolean: ...
    DidActualSizeChange = property(get_DidActualSizeChange, None)
    DidLayoutDirectionChange = property(get_DidLayoutDirectionChange, None)
    DidRasterizationScaleChange = property(get_DidRasterizationScaleChange, None)
    DidSiteEnabledChange = property(get_DidSiteEnabledChange, None)
    DidSiteVisibleChange = property(get_DidSiteVisibleChange, None)
class IContentIslandStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentIslandStatics'
    _iid_ = Guid('{7b9eb7cc-8c43-5e0a-ab23-ab48628fd223}')
    @winrt_commethod(6)
    def Create(self, Root: win32more.Microsoft.UI.Composition.Visual) -> win32more.Microsoft.UI.Content.ContentIsland: ...
    @winrt_commethod(7)
    def FindAllForCompositor(self, compositor: win32more.Microsoft.UI.Composition.Compositor) -> ReceiveArray[win32more.Microsoft.UI.Content.ContentIsland]: ...
    @winrt_commethod(8)
    def FindAllForCurrentThread(self) -> ReceiveArray[win32more.Microsoft.UI.Content.ContentIsland]: ...
    @winrt_commethod(9)
    def GetByVisual(self, child: win32more.Microsoft.UI.Composition.Visual) -> win32more.Microsoft.UI.Content.ContentIsland: ...
    @winrt_commethod(10)
    def GetFromId(self, id: UInt64) -> win32more.Microsoft.UI.Content.ContentIsland: ...
class IContentSite(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentSite'
    _iid_ = Guid('{996c60c4-02b2-5eef-93b0-dd6b1ec2fd7b}')
    @winrt_commethod(6)
    def get_ActualSize(self) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_commethod(7)
    def put_ActualSize(self, value: win32more.Windows.Foundation.Numerics.Vector2) -> Void: ...
    @winrt_commethod(8)
    def get_ClientSize(self) -> win32more.Windows.Graphics.SizeInt32: ...
    @winrt_commethod(9)
    def put_ClientSize(self, value: win32more.Windows.Graphics.SizeInt32) -> Void: ...
    @winrt_commethod(10)
    def get_CoordinateConverter(self) -> win32more.Microsoft.UI.Content.ContentCoordinateConverter: ...
    @winrt_commethod(11)
    def get_DispatcherQueue(self) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
    @winrt_commethod(12)
    def get_Environment(self) -> win32more.Microsoft.UI.Content.ContentSiteEnvironment: ...
    @winrt_commethod(13)
    def get_IsConnected(self) -> Boolean: ...
    @winrt_commethod(14)
    def get_IsSiteEnabled(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_IsSiteEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_IsSiteVisible(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsSiteVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_LayoutDirection(self) -> win32more.Microsoft.UI.Content.ContentLayoutDirection: ...
    @winrt_commethod(19)
    def put_LayoutDirection(self, value: win32more.Microsoft.UI.Content.ContentLayoutDirection) -> Void: ...
    @winrt_commethod(20)
    def get_OverrideScale(self) -> Single: ...
    @winrt_commethod(21)
    def put_OverrideScale(self, value: Single) -> Void: ...
    @winrt_commethod(22)
    def get_ParentScale(self) -> Single: ...
    @winrt_commethod(23)
    def put_ParentScale(self, value: Single) -> Void: ...
    @winrt_commethod(24)
    def get_RasterizationScale(self) -> Single: ...
    @winrt_commethod(25)
    def get_RequestedSize(self) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_commethod(26)
    def get_ShouldApplyRasterizationScale(self) -> Boolean: ...
    @winrt_commethod(27)
    def put_ShouldApplyRasterizationScale(self, value: Boolean) -> Void: ...
    @winrt_commethod(28)
    def get_View(self) -> win32more.Microsoft.UI.Content.ContentSiteView: ...
    @winrt_commethod(29)
    def GetIslandStateChangeDeferral(self) -> win32more.Microsoft.UI.Content.ContentDeferral: ...
    @winrt_commethod(30)
    def add_RequestedStateChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Content.ContentSite, win32more.Microsoft.UI.Content.ContentSiteRequestedStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(31)
    def remove_RequestedStateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ActualSize = property(get_ActualSize, put_ActualSize)
    ClientSize = property(get_ClientSize, put_ClientSize)
    CoordinateConverter = property(get_CoordinateConverter, None)
    DispatcherQueue = property(get_DispatcherQueue, None)
    Environment = property(get_Environment, None)
    IsConnected = property(get_IsConnected, None)
    IsSiteEnabled = property(get_IsSiteEnabled, put_IsSiteEnabled)
    IsSiteVisible = property(get_IsSiteVisible, put_IsSiteVisible)
    LayoutDirection = property(get_LayoutDirection, put_LayoutDirection)
    OverrideScale = property(get_OverrideScale, put_OverrideScale)
    ParentScale = property(get_ParentScale, put_ParentScale)
    RasterizationScale = property(get_RasterizationScale, None)
    RequestedSize = property(get_RequestedSize, None)
    ShouldApplyRasterizationScale = property(get_ShouldApplyRasterizationScale, put_ShouldApplyRasterizationScale)
    View = property(get_View, None)
    RequestedStateChanged = event()
class IContentSiteBridge(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Microsoft.UI.Content.IContentSiteBridge'
    _iid_ = Guid('{faaab99e-a42b-549c-92df-3b6d6e1e368b}')
    @winrt_commethod(6)
    def get_DispatcherQueue(self) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
    @winrt_commethod(7)
    def get_LayoutDirectionOverride(self) -> win32more.Windows.Foundation.IReference[win32more.Microsoft.UI.Content.ContentLayoutDirection]: ...
    @winrt_commethod(8)
    def put_LayoutDirectionOverride(self, value: win32more.Windows.Foundation.IReference[win32more.Microsoft.UI.Content.ContentLayoutDirection]) -> Void: ...
    @winrt_commethod(9)
    def get_OverrideScale(self) -> Single: ...
    @winrt_commethod(10)
    def put_OverrideScale(self, value: Single) -> Void: ...
    DispatcherQueue = property(get_DispatcherQueue, None)
    LayoutDirectionOverride = property(get_LayoutDirectionOverride, put_LayoutDirectionOverride)
    OverrideScale = property(get_OverrideScale, put_OverrideScale)
class IContentSiteEnvironment(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentSiteEnvironment'
    _iid_ = Guid('{685d085d-be53-55d1-aec4-ba2273d5468b}')
    @winrt_commethod(6)
    def get_AppWindowId(self) -> win32more.Microsoft.UI.WindowId: ...
    @winrt_commethod(7)
    def put_AppWindowId(self, value: win32more.Microsoft.UI.WindowId) -> Void: ...
    @winrt_commethod(8)
    def get_DisplayId(self) -> win32more.Microsoft.UI.DisplayId: ...
    @winrt_commethod(9)
    def put_DisplayId(self, value: win32more.Microsoft.UI.DisplayId) -> Void: ...
    @winrt_commethod(10)
    def get_View(self) -> win32more.Microsoft.UI.Content.ContentSiteEnvironmentView: ...
    @winrt_commethod(11)
    def NotifySettingChanged(self, setting: WinRT_String) -> Void: ...
    AppWindowId = property(get_AppWindowId, put_AppWindowId)
    DisplayId = property(get_DisplayId, put_DisplayId)
    View = property(get_View, None)
class IContentSiteEnvironmentFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentSiteEnvironmentFactory'
    _iid_ = Guid('{0befa998-cb15-5f16-a4a5-c0ed1674e186}')
class IContentSiteEnvironmentView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentSiteEnvironmentView'
    _iid_ = Guid('{5b6fe420-0bb3-54dd-8589-786cf02e38f1}')
    @winrt_commethod(6)
    def get_AppWindowId(self) -> win32more.Microsoft.UI.WindowId: ...
    @winrt_commethod(7)
    def get_DisplayId(self) -> win32more.Microsoft.UI.DisplayId: ...
    AppWindowId = property(get_AppWindowId, None)
    DisplayId = property(get_DisplayId, None)
class IContentSiteEnvironmentViewFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentSiteEnvironmentViewFactory'
    _iid_ = Guid('{c901edf2-f184-5a64-8d58-8cf8efa8b678}')
class IContentSiteFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentSiteFactory'
    _iid_ = Guid('{72fb98d5-b28a-57f1-91fa-24c014a342c1}')
class IContentSiteRequestedStateChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentSiteRequestedStateChangedEventArgs'
    _iid_ = Guid('{1b55fd1d-7292-562b-b4a1-d4de7972e684}')
    @winrt_commethod(6)
    def get_DidRequestedSizeChange(self) -> Boolean: ...
    DidRequestedSizeChange = property(get_DidRequestedSizeChange, None)
class IContentSiteView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentSiteView'
    _iid_ = Guid('{2d5d8dd5-358e-5b05-993b-b2666d1786b3}')
    @winrt_commethod(6)
    def get_ActualSize(self) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_commethod(7)
    def get_ClientSize(self) -> win32more.Windows.Graphics.SizeInt32: ...
    @winrt_commethod(8)
    def get_CoordinateConverter(self) -> win32more.Microsoft.UI.Content.ContentCoordinateConverter: ...
    @winrt_commethod(9)
    def get_DispatcherQueue(self) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
    @winrt_commethod(10)
    def get_EnvironmentView(self) -> win32more.Microsoft.UI.Content.ContentSiteEnvironmentView: ...
    @winrt_commethod(11)
    def get_IsConnected(self) -> Boolean: ...
    @winrt_commethod(12)
    def get_IsSiteEnabled(self) -> Boolean: ...
    @winrt_commethod(13)
    def get_IsSiteVisible(self) -> Boolean: ...
    @winrt_commethod(14)
    def get_LayoutDirection(self) -> win32more.Microsoft.UI.Content.ContentLayoutDirection: ...
    @winrt_commethod(15)
    def get_OverrideScale(self) -> Single: ...
    @winrt_commethod(16)
    def get_ParentScale(self) -> Single: ...
    @winrt_commethod(17)
    def get_RasterizationScale(self) -> Single: ...
    @winrt_commethod(18)
    def get_RequestedSize(self) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_commethod(19)
    def get_ShouldApplyRasterizationScale(self) -> Boolean: ...
    ActualSize = property(get_ActualSize, None)
    ClientSize = property(get_ClientSize, None)
    CoordinateConverter = property(get_CoordinateConverter, None)
    DispatcherQueue = property(get_DispatcherQueue, None)
    EnvironmentView = property(get_EnvironmentView, None)
    IsConnected = property(get_IsConnected, None)
    IsSiteEnabled = property(get_IsSiteEnabled, None)
    IsSiteVisible = property(get_IsSiteVisible, None)
    LayoutDirection = property(get_LayoutDirection, None)
    OverrideScale = property(get_OverrideScale, None)
    ParentScale = property(get_ParentScale, None)
    RasterizationScale = property(get_RasterizationScale, None)
    RequestedSize = property(get_RequestedSize, None)
    ShouldApplyRasterizationScale = property(get_ShouldApplyRasterizationScale, None)
class IContentSiteViewFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentSiteViewFactory'
    _iid_ = Guid('{9efd72f0-63ef-5b6a-a50c-5685bd8100f1}')
class IDesktopChildSiteBridge(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IDesktopChildSiteBridge'
    _iid_ = Guid('{b2f2ff7b-1825-51b0-b80b-7599889c569f}')
    @winrt_commethod(6)
    def get_ResizePolicy(self) -> win32more.Microsoft.UI.Content.ContentSizePolicy: ...
    @winrt_commethod(7)
    def put_ResizePolicy(self, value: win32more.Microsoft.UI.Content.ContentSizePolicy) -> Void: ...
    @winrt_commethod(8)
    def get_SiteView(self) -> win32more.Microsoft.UI.Content.ContentSiteView: ...
    ResizePolicy = property(get_ResizePolicy, put_ResizePolicy)
    SiteView = property(get_SiteView, None)
class IDesktopChildSiteBridgeStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IDesktopChildSiteBridgeStatics'
    _iid_ = Guid('{ab6b82de-6a47-5de3-a860-613c8db679ab}')
    @winrt_commethod(6)
    def Create(self, compositor: win32more.Microsoft.UI.Composition.Compositor, parentWindowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.UI.Content.DesktopChildSiteBridge: ...
class IDesktopSiteBridge(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IDesktopSiteBridge'
    _iid_ = Guid('{f0ae8750-905c-50a2-8a12-4545c6245bb4}')
    @winrt_commethod(6)
    def get_IsEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_IsVisible(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_WindowId(self) -> win32more.Microsoft.UI.WindowId: ...
    @winrt_commethod(9)
    def Connect(self, content: win32more.Microsoft.UI.Content.ContentIsland) -> Void: ...
    @winrt_commethod(10)
    def Disable(self) -> Void: ...
    @winrt_commethod(11)
    def Enable(self) -> Void: ...
    @winrt_commethod(12)
    def Hide(self) -> Void: ...
    @winrt_commethod(13)
    def MoveAndResize(self, rect: win32more.Windows.Graphics.RectInt32) -> Void: ...
    @winrt_commethod(14)
    def MoveInZOrderAtBottom(self) -> Void: ...
    @winrt_commethod(15)
    def MoveInZOrderAtTop(self) -> Void: ...
    @winrt_commethod(16)
    def MoveInZOrderBelow(self, windowId: win32more.Microsoft.UI.WindowId) -> Void: ...
    @winrt_commethod(17)
    def Show(self) -> Void: ...
    IsEnabled = property(get_IsEnabled, None)
    IsVisible = property(get_IsVisible, None)
    WindowId = property(get_WindowId, None)
class IDesktopSiteBridgeFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IDesktopSiteBridgeFactory'
    _iid_ = Guid('{d94ee1ff-3af1-54d0-9311-652b29c57c5b}')
class IDesktopSiteBridgeStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Content.IDesktopSiteBridgeStatics'
    _iid_ = Guid('{e0b38daf-9cd4-50c5-83ee-c76e3cf34eba}')
    @winrt_commethod(6)
    def IsSupported(self) -> Boolean: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Devices.Enumeration
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Media.Casting
import win32more.Windows.Storage.Streams
import win32more.Windows.UI.Popups
import win32more.Windows.Win32.System.WinRT
class CastingConnection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Media.Casting.ICastingConnection
    _classid_ = 'Windows.Media.Casting.CastingConnection'
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Media.Casting.ICastingConnection) -> win32more.Windows.Media.Casting.CastingConnectionState: ...
    @winrt_mixinmethod
    def get_Device(self: win32more.Windows.Media.Casting.ICastingConnection) -> win32more.Windows.Media.Casting.CastingDevice: ...
    @winrt_mixinmethod
    def get_Source(self: win32more.Windows.Media.Casting.ICastingConnection) -> win32more.Windows.Media.Casting.CastingSource: ...
    @winrt_mixinmethod
    def put_Source(self: win32more.Windows.Media.Casting.ICastingConnection, value: win32more.Windows.Media.Casting.CastingSource) -> Void: ...
    @winrt_mixinmethod
    def add_StateChanged(self: win32more.Windows.Media.Casting.ICastingConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.Casting.CastingConnection, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_StateChanged(self: win32more.Windows.Media.Casting.ICastingConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ErrorOccurred(self: win32more.Windows.Media.Casting.ICastingConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.Casting.CastingConnection, win32more.Windows.Media.Casting.CastingConnectionErrorOccurredEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ErrorOccurred(self: win32more.Windows.Media.Casting.ICastingConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def RequestStartCastingAsync(self: win32more.Windows.Media.Casting.ICastingConnection, value: win32more.Windows.Media.Casting.CastingSource) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Casting.CastingConnectionErrorStatus]: ...
    @winrt_mixinmethod
    def DisconnectAsync(self: win32more.Windows.Media.Casting.ICastingConnection) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Casting.CastingConnectionErrorStatus]: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    Device = property(get_Device, None)
    Source = property(get_Source, put_Source)
    State = property(get_State, None)
    StateChanged = event()
    ErrorOccurred = event()
class CastingConnectionErrorOccurredEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Casting.ICastingConnectionErrorOccurredEventArgs
    _classid_ = 'Windows.Media.Casting.CastingConnectionErrorOccurredEventArgs'
    @winrt_mixinmethod
    def get_ErrorStatus(self: win32more.Windows.Media.Casting.ICastingConnectionErrorOccurredEventArgs) -> win32more.Windows.Media.Casting.CastingConnectionErrorStatus: ...
    @winrt_mixinmethod
    def get_Message(self: win32more.Windows.Media.Casting.ICastingConnectionErrorOccurredEventArgs) -> WinRT_String: ...
    ErrorStatus = property(get_ErrorStatus, None)
    Message = property(get_Message, None)
class CastingConnectionErrorStatus(Enum, Int32):
    Succeeded = 0
    DeviceDidNotRespond = 1
    DeviceError = 2
    DeviceLocked = 3
    ProtectedPlaybackFailed = 4
    InvalidCastingSource = 5
    Unknown = 6
class CastingConnectionState(Enum, Int32):
    Disconnected = 0
    Connected = 1
    Rendering = 2
    Disconnecting = 3
    Connecting = 4
class CastingDevice(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Casting.ICastingDevice
    _classid_ = 'Windows.Media.Casting.CastingDevice'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Media.Casting.ICastingDevice) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_FriendlyName(self: win32more.Windows.Media.Casting.ICastingDevice) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Icon(self: win32more.Windows.Media.Casting.ICastingDevice) -> win32more.Windows.Storage.Streams.IRandomAccessStreamWithContentType: ...
    @winrt_mixinmethod
    def GetSupportedCastingPlaybackTypesAsync(self: win32more.Windows.Media.Casting.ICastingDevice) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Casting.CastingPlaybackTypes]: ...
    @winrt_mixinmethod
    def CreateCastingConnection(self: win32more.Windows.Media.Casting.ICastingDevice) -> win32more.Windows.Media.Casting.CastingConnection: ...
    @winrt_classmethod
    def GetDeviceSelector(cls: win32more.Windows.Media.Casting.ICastingDeviceStatics, type: win32more.Windows.Media.Casting.CastingPlaybackTypes) -> WinRT_String: ...
    @winrt_classmethod
    def GetDeviceSelectorFromCastingSourceAsync(cls: win32more.Windows.Media.Casting.ICastingDeviceStatics, castingSource: win32more.Windows.Media.Casting.CastingSource) -> win32more.Windows.Foundation.IAsyncOperation[WinRT_String]: ...
    @winrt_classmethod
    def FromIdAsync(cls: win32more.Windows.Media.Casting.ICastingDeviceStatics, value: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Casting.CastingDevice]: ...
    @winrt_classmethod
    def DeviceInfoSupportsCastingAsync(cls: win32more.Windows.Media.Casting.ICastingDeviceStatics, device: win32more.Windows.Devices.Enumeration.DeviceInformation) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    FriendlyName = property(get_FriendlyName, None)
    Icon = property(get_Icon, None)
    Id = property(get_Id, None)
class CastingDevicePicker(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Casting.ICastingDevicePicker
    _classid_ = 'Windows.Media.Casting.CastingDevicePicker'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Media.Casting.CastingDevicePicker.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Media.Casting.CastingDevicePicker: ...
    @winrt_mixinmethod
    def get_Filter(self: win32more.Windows.Media.Casting.ICastingDevicePicker) -> win32more.Windows.Media.Casting.CastingDevicePickerFilter: ...
    @winrt_mixinmethod
    def get_Appearance(self: win32more.Windows.Media.Casting.ICastingDevicePicker) -> win32more.Windows.Devices.Enumeration.DevicePickerAppearance: ...
    @winrt_mixinmethod
    def add_CastingDeviceSelected(self: win32more.Windows.Media.Casting.ICastingDevicePicker, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.Casting.CastingDevicePicker, win32more.Windows.Media.Casting.CastingDeviceSelectedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CastingDeviceSelected(self: win32more.Windows.Media.Casting.ICastingDevicePicker, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_CastingDevicePickerDismissed(self: win32more.Windows.Media.Casting.ICastingDevicePicker, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.Casting.CastingDevicePicker, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CastingDevicePickerDismissed(self: win32more.Windows.Media.Casting.ICastingDevicePicker, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Show(self: win32more.Windows.Media.Casting.ICastingDevicePicker, selection: win32more.Windows.Foundation.Rect) -> Void: ...
    @winrt_mixinmethod
    def ShowWithPlacement(self: win32more.Windows.Media.Casting.ICastingDevicePicker, selection: win32more.Windows.Foundation.Rect, preferredPlacement: win32more.Windows.UI.Popups.Placement) -> Void: ...
    @winrt_mixinmethod
    def Hide(self: win32more.Windows.Media.Casting.ICastingDevicePicker) -> Void: ...
    Appearance = property(get_Appearance, None)
    Filter = property(get_Filter, None)
    CastingDeviceSelected = event()
    CastingDevicePickerDismissed = event()
class CastingDevicePickerFilter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Casting.ICastingDevicePickerFilter
    _classid_ = 'Windows.Media.Casting.CastingDevicePickerFilter'
    @winrt_mixinmethod
    def get_SupportsAudio(self: win32more.Windows.Media.Casting.ICastingDevicePickerFilter) -> Boolean: ...
    @winrt_mixinmethod
    def put_SupportsAudio(self: win32more.Windows.Media.Casting.ICastingDevicePickerFilter, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SupportsVideo(self: win32more.Windows.Media.Casting.ICastingDevicePickerFilter) -> Boolean: ...
    @winrt_mixinmethod
    def put_SupportsVideo(self: win32more.Windows.Media.Casting.ICastingDevicePickerFilter, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SupportsPictures(self: win32more.Windows.Media.Casting.ICastingDevicePickerFilter) -> Boolean: ...
    @winrt_mixinmethod
    def put_SupportsPictures(self: win32more.Windows.Media.Casting.ICastingDevicePickerFilter, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SupportedCastingSources(self: win32more.Windows.Media.Casting.ICastingDevicePickerFilter) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Media.Casting.CastingSource]: ...
    SupportedCastingSources = property(get_SupportedCastingSources, None)
    SupportsAudio = property(get_SupportsAudio, put_SupportsAudio)
    SupportsPictures = property(get_SupportsPictures, put_SupportsPictures)
    SupportsVideo = property(get_SupportsVideo, put_SupportsVideo)
class CastingDeviceSelectedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Casting.ICastingDeviceSelectedEventArgs
    _classid_ = 'Windows.Media.Casting.CastingDeviceSelectedEventArgs'
    @winrt_mixinmethod
    def get_SelectedCastingDevice(self: win32more.Windows.Media.Casting.ICastingDeviceSelectedEventArgs) -> win32more.Windows.Media.Casting.CastingDevice: ...
    SelectedCastingDevice = property(get_SelectedCastingDevice, None)
class CastingPlaybackTypes(Enum, UInt32):
    None_ = 0
    Audio = 1
    Video = 2
    Picture = 4
class CastingSource(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Casting.ICastingSource
    _classid_ = 'Windows.Media.Casting.CastingSource'
    @winrt_mixinmethod
    def get_PreferredSourceUri(self: win32more.Windows.Media.Casting.ICastingSource) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_PreferredSourceUri(self: win32more.Windows.Media.Casting.ICastingSource, value: win32more.Windows.Foundation.Uri) -> Void: ...
    PreferredSourceUri = property(get_PreferredSourceUri, put_PreferredSourceUri)
class ICastingConnection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Windows.Media.Casting.ICastingConnection'
    _iid_ = Guid('{cd951653-c2f1-4498-8b78-5fb4cd3640dd}')
    @winrt_commethod(6)
    def get_State(self) -> win32more.Windows.Media.Casting.CastingConnectionState: ...
    @winrt_commethod(7)
    def get_Device(self) -> win32more.Windows.Media.Casting.CastingDevice: ...
    @winrt_commethod(8)
    def get_Source(self) -> win32more.Windows.Media.Casting.CastingSource: ...
    @winrt_commethod(9)
    def put_Source(self, value: win32more.Windows.Media.Casting.CastingSource) -> Void: ...
    @winrt_commethod(10)
    def add_StateChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.Casting.CastingConnection, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_StateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def add_ErrorOccurred(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.Casting.CastingConnection, win32more.Windows.Media.Casting.CastingConnectionErrorOccurredEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_ErrorOccurred(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def RequestStartCastingAsync(self, value: win32more.Windows.Media.Casting.CastingSource) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Casting.CastingConnectionErrorStatus]: ...
    @winrt_commethod(15)
    def DisconnectAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Casting.CastingConnectionErrorStatus]: ...
    Device = property(get_Device, None)
    Source = property(get_Source, put_Source)
    State = property(get_State, None)
    StateChanged = event()
    ErrorOccurred = event()
class ICastingConnectionErrorOccurredEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Casting.ICastingConnectionErrorOccurredEventArgs'
    _iid_ = Guid('{a7fb3c69-8719-4f00-81fb-961863c79a32}')
    @winrt_commethod(6)
    def get_ErrorStatus(self) -> win32more.Windows.Media.Casting.CastingConnectionErrorStatus: ...
    @winrt_commethod(7)
    def get_Message(self) -> WinRT_String: ...
    ErrorStatus = property(get_ErrorStatus, None)
    Message = property(get_Message, None)
class ICastingDevice(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Casting.ICastingDevice'
    _iid_ = Guid('{de721c83-4a43-4ad1-a6d2-2492a796c3f2}')
    @winrt_commethod(6)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_FriendlyName(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_Icon(self) -> win32more.Windows.Storage.Streams.IRandomAccessStreamWithContentType: ...
    @winrt_commethod(9)
    def GetSupportedCastingPlaybackTypesAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Casting.CastingPlaybackTypes]: ...
    @winrt_commethod(10)
    def CreateCastingConnection(self) -> win32more.Windows.Media.Casting.CastingConnection: ...
    FriendlyName = property(get_FriendlyName, None)
    Icon = property(get_Icon, None)
    Id = property(get_Id, None)
class ICastingDevicePicker(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Casting.ICastingDevicePicker'
    _iid_ = Guid('{dcd39924-0591-49be-aacb-4b82ee756a95}')
    @winrt_commethod(6)
    def get_Filter(self) -> win32more.Windows.Media.Casting.CastingDevicePickerFilter: ...
    @winrt_commethod(7)
    def get_Appearance(self) -> win32more.Windows.Devices.Enumeration.DevicePickerAppearance: ...
    @winrt_commethod(8)
    def add_CastingDeviceSelected(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.Casting.CastingDevicePicker, win32more.Windows.Media.Casting.CastingDeviceSelectedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_CastingDeviceSelected(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def add_CastingDevicePickerDismissed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.Casting.CastingDevicePicker, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_CastingDevicePickerDismissed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def Show(self, selection: win32more.Windows.Foundation.Rect) -> Void: ...
    @winrt_commethod(13)
    def ShowWithPlacement(self, selection: win32more.Windows.Foundation.Rect, preferredPlacement: win32more.Windows.UI.Popups.Placement) -> Void: ...
    @winrt_commethod(14)
    def Hide(self) -> Void: ...
    Appearance = property(get_Appearance, None)
    Filter = property(get_Filter, None)
    CastingDeviceSelected = event()
    CastingDevicePickerDismissed = event()
class ICastingDevicePickerFilter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Casting.ICastingDevicePickerFilter'
    _iid_ = Guid('{be8c619c-b563-4354-ae33-9fdaad8c6291}')
    @winrt_commethod(6)
    def get_SupportsAudio(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_SupportsAudio(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_SupportsVideo(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_SupportsVideo(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_SupportsPictures(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_SupportsPictures(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_SupportedCastingSources(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Media.Casting.CastingSource]: ...
    SupportedCastingSources = property(get_SupportedCastingSources, None)
    SupportsAudio = property(get_SupportsAudio, put_SupportsAudio)
    SupportsPictures = property(get_SupportsPictures, put_SupportsPictures)
    SupportsVideo = property(get_SupportsVideo, put_SupportsVideo)
class ICastingDeviceSelectedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Casting.ICastingDeviceSelectedEventArgs'
    _iid_ = Guid('{dc439e86-dd57-4d0d-9400-af45e4fb3663}')
    @winrt_commethod(6)
    def get_SelectedCastingDevice(self) -> win32more.Windows.Media.Casting.CastingDevice: ...
    SelectedCastingDevice = property(get_SelectedCastingDevice, None)
class ICastingDeviceStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Casting.ICastingDeviceStatics'
    _iid_ = Guid('{e7d958d7-4d13-4237-a365-4c4f6a4cfd2f}')
    @winrt_commethod(6)
    def GetDeviceSelector(self, type: win32more.Windows.Media.Casting.CastingPlaybackTypes) -> WinRT_String: ...
    @winrt_commethod(7)
    def GetDeviceSelectorFromCastingSourceAsync(self, castingSource: win32more.Windows.Media.Casting.CastingSource) -> win32more.Windows.Foundation.IAsyncOperation[WinRT_String]: ...
    @winrt_commethod(8)
    def FromIdAsync(self, value: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Casting.CastingDevice]: ...
    @winrt_commethod(9)
    def DeviceInfoSupportsCastingAsync(self, device: win32more.Windows.Devices.Enumeration.DeviceInformation) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
class ICastingSource(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Casting.ICastingSource'
    _iid_ = Guid('{f429ea72-3467-47e6-a027-522923e9d727}')
    @winrt_commethod(6)
    def get_PreferredSourceUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def put_PreferredSourceUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    PreferredSourceUri = property(get_PreferredSourceUri, put_PreferredSourceUri)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Media.Audio
import win32more.Windows.Win32.Media.Audio.XAudio2
import win32more.Windows.Win32.System.Com
FXEQ_MIN_FRAMERATE: UInt32 = 22000
FXEQ_MAX_FRAMERATE: UInt32 = 48000
FXEQ_MIN_FREQUENCY_CENTER: Single = 20
FXEQ_MAX_FREQUENCY_CENTER: Single = 20000
FXEQ_DEFAULT_FREQUENCY_CENTER_0: Single = 100
FXEQ_DEFAULT_FREQUENCY_CENTER_1: Single = 800
FXEQ_DEFAULT_FREQUENCY_CENTER_2: Single = 2000
FXEQ_DEFAULT_FREQUENCY_CENTER_3: Single = 10000
FXEQ_MIN_GAIN: Single = 0.126
FXEQ_MAX_GAIN: Single = 7.94
FXEQ_DEFAULT_GAIN: Single = 1
FXEQ_MIN_BANDWIDTH: Single = 0.1
FXEQ_MAX_BANDWIDTH: Single = 2
FXEQ_DEFAULT_BANDWIDTH: Single = 1
FXMASTERINGLIMITER_MIN_RELEASE: UInt32 = 1
FXMASTERINGLIMITER_MAX_RELEASE: UInt32 = 20
FXMASTERINGLIMITER_DEFAULT_RELEASE: UInt32 = 6
FXMASTERINGLIMITER_MIN_LOUDNESS: UInt32 = 1
FXMASTERINGLIMITER_MAX_LOUDNESS: UInt32 = 1800
FXMASTERINGLIMITER_DEFAULT_LOUDNESS: UInt32 = 1000
FXREVERB_MIN_DIFFUSION: Single = 0
FXREVERB_MAX_DIFFUSION: Single = 1
FXREVERB_DEFAULT_DIFFUSION: Single = 0.9
FXREVERB_MIN_ROOMSIZE: Single = 0.0001
FXREVERB_MAX_ROOMSIZE: Single = 1
FXREVERB_DEFAULT_ROOMSIZE: Single = 0.6
FXLOUDNESS_DEFAULT_MOMENTARY_MS: UInt32 = 400
FXLOUDNESS_DEFAULT_SHORTTERM_MS: UInt32 = 3000
FXECHO_MIN_WETDRYMIX: Single = 0
FXECHO_MAX_WETDRYMIX: Single = 1
FXECHO_DEFAULT_WETDRYMIX: Single = 0.5
FXECHO_MIN_FEEDBACK: Single = 0
FXECHO_MAX_FEEDBACK: Single = 1
FXECHO_DEFAULT_FEEDBACK: Single = 0.5
FXECHO_MIN_DELAY: Single = 1
FXECHO_MAX_DELAY: Single = 2000
FXECHO_DEFAULT_DELAY: Single = 500
XAUDIO2_DLL_A: String = 'xaudio2_9.dll'
XAUDIO2_DLL_W: String = 'xaudio2_9.dll'
XAUDIO2D_DLL_A: String = 'xaudio2_9d.dll'
XAUDIO2D_DLL_W: String = 'xaudio2_9d.dll'
XAUDIO2_DLL: String = 'xaudio2_9.dll'
XAUDIO2D_DLL: String = 'xaudio2_9d.dll'
XAUDIO2_MAX_BUFFER_BYTES: UInt32 = 2147483648
XAUDIO2_MAX_QUEUED_BUFFERS: UInt32 = 64
XAUDIO2_MAX_BUFFERS_SYSTEM: UInt32 = 2
XAUDIO2_MAX_AUDIO_CHANNELS: UInt32 = 64
XAUDIO2_MIN_SAMPLE_RATE: UInt32 = 1000
XAUDIO2_MAX_SAMPLE_RATE: UInt32 = 200000
XAUDIO2_MAX_VOLUME_LEVEL: Single = 16777216
XAUDIO2_MAX_FREQ_RATIO: Single = 1024
XAUDIO2_DEFAULT_FREQ_RATIO: Single = 2
XAUDIO2_MAX_FILTER_ONEOVERQ: Single = 1.5
XAUDIO2_MAX_FILTER_FREQUENCY: Single = 1
XAUDIO2_MAX_LOOP_COUNT: UInt32 = 254
XAUDIO2_MAX_INSTANCES: UInt32 = 8
XAUDIO2_MAX_RATIO_TIMES_RATE_XMA_MONO: UInt32 = 600000
XAUDIO2_MAX_RATIO_TIMES_RATE_XMA_MULTICHANNEL: UInt32 = 300000
XAUDIO2_COMMIT_NOW: UInt32 = 0
XAUDIO2_COMMIT_ALL: UInt32 = 0
XAUDIO2_NO_LOOP_REGION: UInt32 = 0
XAUDIO2_LOOP_INFINITE: UInt32 = 255
XAUDIO2_DEFAULT_CHANNELS: UInt32 = 0
XAUDIO2_DEFAULT_SAMPLERATE: UInt32 = 0
XAUDIO2_DEBUG_ENGINE: UInt32 = 1
XAUDIO2_VOICE_NOPITCH: UInt32 = 2
XAUDIO2_VOICE_NOSRC: UInt32 = 4
XAUDIO2_VOICE_USEFILTER: UInt32 = 8
XAUDIO2_PLAY_TAILS: UInt32 = 32
XAUDIO2_END_OF_STREAM: UInt32 = 64
XAUDIO2_SEND_USEFILTER: UInt32 = 128
XAUDIO2_VOICE_NOSAMPLESPLAYED: UInt32 = 256
XAUDIO2_STOP_ENGINE_WHEN_IDLE: UInt32 = 8192
XAUDIO2_1024_QUANTUM: UInt32 = 32768
XAUDIO2_NO_VIRTUAL_AUDIO_CLIENT: UInt32 = 65536
XAUDIO2_DEFAULT_FILTER_FREQUENCY: Single = 1
XAUDIO2_DEFAULT_FILTER_ONEOVERQ: Single = 1
XAUDIO2_QUANTUM_NUMERATOR: UInt32 = 1
XAUDIO2_QUANTUM_DENOMINATOR: UInt32 = 100
FACILITY_XAUDIO2: UInt32 = 2198
XAUDIO2_E_INVALID_CALL: win32more.Windows.Win32.Foundation.HRESULT = -2003435519
XAUDIO2_E_XMA_DECODER_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2003435518
XAUDIO2_E_XAPO_CREATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2003435517
XAUDIO2_E_DEVICE_INVALIDATED: win32more.Windows.Win32.Foundation.HRESULT = -2003435516
Processor1: UInt32 = 1
Processor2: UInt32 = 2
Processor3: UInt32 = 4
Processor4: UInt32 = 8
Processor5: UInt32 = 16
Processor6: UInt32 = 32
Processor7: UInt32 = 64
Processor8: UInt32 = 128
Processor9: UInt32 = 256
Processor10: UInt32 = 512
Processor11: UInt32 = 1024
Processor12: UInt32 = 2048
Processor13: UInt32 = 4096
Processor14: UInt32 = 8192
Processor15: UInt32 = 16384
Processor16: UInt32 = 32768
Processor17: UInt32 = 65536
Processor18: UInt32 = 131072
Processor19: UInt32 = 262144
Processor20: UInt32 = 524288
Processor21: UInt32 = 1048576
Processor22: UInt32 = 2097152
Processor23: UInt32 = 4194304
Processor24: UInt32 = 8388608
Processor25: UInt32 = 16777216
Processor26: UInt32 = 33554432
Processor27: UInt32 = 67108864
Processor28: UInt32 = 134217728
Processor29: UInt32 = 268435456
Processor30: UInt32 = 536870912
Processor31: UInt32 = 1073741824
Processor32: UInt32 = 2147483648
XAUDIO2_ANY_PROCESSOR: UInt32 = 4294967295
XAUDIO2_USE_DEFAULT_PROCESSOR: UInt32 = 0
XAUDIO2_DEFAULT_PROCESSOR: UInt32 = 1
XAUDIO2_LOG_ERRORS: UInt32 = 1
XAUDIO2_LOG_WARNINGS: UInt32 = 2
XAUDIO2_LOG_INFO: UInt32 = 4
XAUDIO2_LOG_DETAIL: UInt32 = 8
XAUDIO2_LOG_API_CALLS: UInt32 = 16
XAUDIO2_LOG_FUNC_CALLS: UInt32 = 32
XAUDIO2_LOG_TIMING: UInt32 = 64
XAUDIO2_LOG_LOCKS: UInt32 = 128
XAUDIO2_LOG_MEMORY: UInt32 = 256
XAUDIO2_LOG_STREAMING: UInt32 = 4096
XAUDIO2FX_REVERB_MIN_FRAMERATE: UInt32 = 20000
XAUDIO2FX_REVERB_MAX_FRAMERATE: UInt32 = 48000
XAUDIO2FX_REVERB_MIN_WET_DRY_MIX: Single = 0
XAUDIO2FX_REVERB_MIN_REFLECTIONS_DELAY: UInt32 = 0
XAUDIO2FX_REVERB_MIN_REVERB_DELAY: UInt32 = 0
XAUDIO2FX_REVERB_MIN_REAR_DELAY: UInt32 = 0
XAUDIO2FX_REVERB_MIN_7POINT1_SIDE_DELAY: UInt32 = 0
XAUDIO2FX_REVERB_MIN_7POINT1_REAR_DELAY: UInt32 = 0
XAUDIO2FX_REVERB_MIN_POSITION: UInt32 = 0
XAUDIO2FX_REVERB_MIN_DIFFUSION: UInt32 = 0
XAUDIO2FX_REVERB_MIN_LOW_EQ_GAIN: UInt32 = 0
XAUDIO2FX_REVERB_MIN_LOW_EQ_CUTOFF: UInt32 = 0
XAUDIO2FX_REVERB_MIN_HIGH_EQ_GAIN: UInt32 = 0
XAUDIO2FX_REVERB_MIN_HIGH_EQ_CUTOFF: UInt32 = 0
XAUDIO2FX_REVERB_MIN_ROOM_FILTER_FREQ: Single = 20
XAUDIO2FX_REVERB_MIN_ROOM_FILTER_MAIN: Single = -100
XAUDIO2FX_REVERB_MIN_ROOM_FILTER_HF: Single = -100
XAUDIO2FX_REVERB_MIN_REFLECTIONS_GAIN: Single = -100
XAUDIO2FX_REVERB_MIN_REVERB_GAIN: Single = -100
XAUDIO2FX_REVERB_MIN_DECAY_TIME: Single = 0.1
XAUDIO2FX_REVERB_MIN_DENSITY: Single = 0
XAUDIO2FX_REVERB_MIN_ROOM_SIZE: Single = 0
XAUDIO2FX_REVERB_MAX_WET_DRY_MIX: Single = 100
XAUDIO2FX_REVERB_MAX_REFLECTIONS_DELAY: UInt32 = 300
XAUDIO2FX_REVERB_MAX_REVERB_DELAY: UInt32 = 85
XAUDIO2FX_REVERB_MAX_REAR_DELAY: UInt32 = 5
XAUDIO2FX_REVERB_MAX_7POINT1_SIDE_DELAY: UInt32 = 5
XAUDIO2FX_REVERB_MAX_7POINT1_REAR_DELAY: UInt32 = 20
XAUDIO2FX_REVERB_MAX_POSITION: UInt32 = 30
XAUDIO2FX_REVERB_MAX_DIFFUSION: UInt32 = 15
XAUDIO2FX_REVERB_MAX_LOW_EQ_GAIN: UInt32 = 12
XAUDIO2FX_REVERB_MAX_LOW_EQ_CUTOFF: UInt32 = 9
XAUDIO2FX_REVERB_MAX_HIGH_EQ_GAIN: UInt32 = 8
XAUDIO2FX_REVERB_MAX_HIGH_EQ_CUTOFF: UInt32 = 14
XAUDIO2FX_REVERB_MAX_ROOM_FILTER_FREQ: Single = 20000
XAUDIO2FX_REVERB_MAX_ROOM_FILTER_MAIN: Single = 0
XAUDIO2FX_REVERB_MAX_ROOM_FILTER_HF: Single = 0
XAUDIO2FX_REVERB_MAX_REFLECTIONS_GAIN: Single = 20
XAUDIO2FX_REVERB_MAX_REVERB_GAIN: Single = 20
XAUDIO2FX_REVERB_MAX_DENSITY: Single = 100
XAUDIO2FX_REVERB_MAX_ROOM_SIZE: Single = 100
XAUDIO2FX_REVERB_DEFAULT_WET_DRY_MIX: Single = 100
XAUDIO2FX_REVERB_DEFAULT_REFLECTIONS_DELAY: UInt32 = 5
XAUDIO2FX_REVERB_DEFAULT_REVERB_DELAY: UInt32 = 5
XAUDIO2FX_REVERB_DEFAULT_REAR_DELAY: UInt32 = 5
XAUDIO2FX_REVERB_DEFAULT_7POINT1_SIDE_DELAY: UInt32 = 5
XAUDIO2FX_REVERB_DEFAULT_7POINT1_REAR_DELAY: UInt32 = 20
XAUDIO2FX_REVERB_DEFAULT_POSITION: UInt32 = 6
XAUDIO2FX_REVERB_DEFAULT_POSITION_MATRIX: UInt32 = 27
XAUDIO2FX_REVERB_DEFAULT_EARLY_DIFFUSION: UInt32 = 8
XAUDIO2FX_REVERB_DEFAULT_LATE_DIFFUSION: UInt32 = 8
XAUDIO2FX_REVERB_DEFAULT_LOW_EQ_GAIN: UInt32 = 8
XAUDIO2FX_REVERB_DEFAULT_LOW_EQ_CUTOFF: UInt32 = 4
XAUDIO2FX_REVERB_DEFAULT_HIGH_EQ_GAIN: UInt32 = 8
XAUDIO2FX_REVERB_DEFAULT_HIGH_EQ_CUTOFF: UInt32 = 4
XAUDIO2FX_REVERB_DEFAULT_ROOM_FILTER_FREQ: Single = 5000
XAUDIO2FX_REVERB_DEFAULT_ROOM_FILTER_MAIN: Single = 0
XAUDIO2FX_REVERB_DEFAULT_ROOM_FILTER_HF: Single = 0
XAUDIO2FX_REVERB_DEFAULT_REFLECTIONS_GAIN: Single = 0
XAUDIO2FX_REVERB_DEFAULT_REVERB_GAIN: Single = 0
XAUDIO2FX_REVERB_DEFAULT_DECAY_TIME: Single = 1
XAUDIO2FX_REVERB_DEFAULT_DENSITY: Single = 100
XAUDIO2FX_REVERB_DEFAULT_ROOM_SIZE: Single = 100
XAUDIO2FX_REVERB_DEFAULT_DISABLE_LATE_FIELD: UInt32 = 0
HRTF_MAX_GAIN_LIMIT: Single = 12
HRTF_MIN_GAIN_LIMIT: Single = -96
HRTF_MIN_UNITY_GAIN_DISTANCE: Single = 0.05
HRTF_DEFAULT_UNITY_GAIN_DISTANCE: Single = 1
FACILITY_XAPO: UInt32 = 2199
XAPO_E_FORMAT_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2003369983
XAPO_MIN_CHANNELS: UInt32 = 1
XAPO_MAX_CHANNELS: UInt32 = 64
XAPO_MIN_FRAMERATE: UInt32 = 1000
XAPO_MAX_FRAMERATE: UInt32 = 200000
XAPO_REGISTRATION_STRING_LENGTH: UInt32 = 256
XAPO_FLAG_CHANNELS_MUST_MATCH: UInt32 = 1
XAPO_FLAG_FRAMERATE_MUST_MATCH: UInt32 = 2
XAPO_FLAG_BITSPERSAMPLE_MUST_MATCH: UInt32 = 4
XAPO_FLAG_BUFFERCOUNT_MUST_MATCH: UInt32 = 8
XAPO_FLAG_INPLACE_REQUIRED: UInt32 = 32
XAPO_FLAG_INPLACE_SUPPORTED: UInt32 = 16
SPEAKER_MONO: UInt32 = 4
X3DAUDIO_HANDLE_BYTESIZE: UInt32 = 20
X3DAUDIO_PI: Single = 3.1415927
X3DAUDIO_2PI: Single = 6.2831855
X3DAUDIO_SPEED_OF_SOUND: Single = 343.5
X3DAUDIO_CALCULATE_MATRIX: UInt32 = 1
X3DAUDIO_CALCULATE_DELAY: UInt32 = 2
X3DAUDIO_CALCULATE_LPF_DIRECT: UInt32 = 4
X3DAUDIO_CALCULATE_LPF_REVERB: UInt32 = 8
X3DAUDIO_CALCULATE_REVERB: UInt32 = 16
X3DAUDIO_CALCULATE_DOPPLER: UInt32 = 32
X3DAUDIO_CALCULATE_EMITTER_ANGLE: UInt32 = 64
X3DAUDIO_CALCULATE_ZEROCENTER: UInt32 = 65536
X3DAUDIO_CALCULATE_REDIRECT_TO_LFE: UInt32 = 131072
@cfunctype('XAudio2_8.dll')
def CreateFX(clsid: POINTER(Guid), pEffect: POINTER(win32more.Windows.Win32.System.Com.IUnknown), pInitDat: VoidPtr, InitDataByteSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('XAudio2_8.dll')
def XAudio2CreateWithVersionInfo(ppXAudio2: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.IXAudio2), Flags: UInt32, XAudio2Processor: UInt32, ntddiVersion: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('XAudio2_8.dll')
def CreateAudioVolumeMeter(ppApo: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('XAudio2_8.dll')
def CreateAudioReverb(ppApo: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('HrtfApo.dll')
def CreateHrtfApo(init: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.HrtfApoInit), xApo: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.IXAPO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
AudioReverb = Guid('{c2633b16-471b-4498-b8c5-4f0959e2ec09}')
AudioVolumeMeter = Guid('{4fc3b166-972a-40cf-bc37-7db03db2fba3}')
class FXECHO_INITDATA(Structure):
    MaxDelay: Single
    _pack_ = 1
class FXECHO_PARAMETERS(Structure):
    WetDryMix: Single
    Feedback: Single
    Delay: Single
    _pack_ = 1
FXEQ = Guid('{f5e01117-d6c4-485a-a3f5-695196f3dbfa}')
class FXEQ_PARAMETERS(Structure):
    FrequencyCenter0: Single
    Gain0: Single
    Bandwidth0: Single
    FrequencyCenter1: Single
    Gain1: Single
    Bandwidth1: Single
    FrequencyCenter2: Single
    Gain2: Single
    Bandwidth2: Single
    FrequencyCenter3: Single
    Gain3: Single
    Bandwidth3: Single
    _pack_ = 1
FXEcho = Guid('{5039d740-f736-449a-84d3-a56202557b87}')
class FXMASTERINGLIMITER_PARAMETERS(Structure):
    Release: UInt32
    Loudness: UInt32
    _pack_ = 1
FXMasteringLimiter = Guid('{c4137916-2be1-46fd-8599-441536f49856}')
class FXREVERB_PARAMETERS(Structure):
    Diffusion: Single
    RoomSize: Single
    _pack_ = 1
FXReverb = Guid('{7d9aca56-cb68-4807-b632-b137352e8596}')
class HrtfApoInit(Structure):
    distanceDecay: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.HrtfDistanceDecay)
    directivity: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.HrtfDirectivity)
class HrtfDirectivity(Structure):
    type: win32more.Windows.Win32.Media.Audio.XAudio2.HrtfDirectivityType
    scaling: Single
class HrtfDirectivityCardioid(Structure):
    directivity: win32more.Windows.Win32.Media.Audio.XAudio2.HrtfDirectivity
    order: Single
class HrtfDirectivityCone(Structure):
    directivity: win32more.Windows.Win32.Media.Audio.XAudio2.HrtfDirectivity
    innerAngle: Single
    outerAngle: Single
HrtfDirectivityType = Int32
OmniDirectional: win32more.Windows.Win32.Media.Audio.XAudio2.HrtfDirectivityType = 0
Cardioid: win32more.Windows.Win32.Media.Audio.XAudio2.HrtfDirectivityType = 1
Cone: win32more.Windows.Win32.Media.Audio.XAudio2.HrtfDirectivityType = 2
class HrtfDistanceDecay(Structure):
    type: win32more.Windows.Win32.Media.Audio.XAudio2.HrtfDistanceDecayType
    maxGain: Single
    minGain: Single
    unityGainDistance: Single
    cutoffDistance: Single
HrtfDistanceDecayType = Int32
NaturalDecay: win32more.Windows.Win32.Media.Audio.XAudio2.HrtfDistanceDecayType = 0
CustomDecay: win32more.Windows.Win32.Media.Audio.XAudio2.HrtfDistanceDecayType = 1
HrtfEnvironment = Int32
Small: win32more.Windows.Win32.Media.Audio.XAudio2.HrtfEnvironment = 0
Medium: win32more.Windows.Win32.Media.Audio.XAudio2.HrtfEnvironment = 1
Large: win32more.Windows.Win32.Media.Audio.XAudio2.HrtfEnvironment = 2
Outdoors: win32more.Windows.Win32.Media.Audio.XAudio2.HrtfEnvironment = 3
class HrtfOrientation(Structure):
    element: Single * 9
class HrtfPosition(Structure):
    x: Single
    y: Single
    z: Single
class IXAPO(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a410b984-9839-4819-a0be-2856ae6b3adb}')
    @commethod(3)
    def GetRegistrationProperties(self, ppRegistrationProperties: POINTER(POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAPO_REGISTRATION_PROPERTIES))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def IsInputFormatSupported(self, pOutputFormat: POINTER(win32more.Windows.Win32.Media.Audio.WAVEFORMATEX), pRequestedInputFormat: POINTER(win32more.Windows.Win32.Media.Audio.WAVEFORMATEX), ppSupportedInputFormat: POINTER(POINTER(win32more.Windows.Win32.Media.Audio.WAVEFORMATEX))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def IsOutputFormatSupported(self, pInputFormat: POINTER(win32more.Windows.Win32.Media.Audio.WAVEFORMATEX), pRequestedOutputFormat: POINTER(win32more.Windows.Win32.Media.Audio.WAVEFORMATEX), ppSupportedOutputFormat: POINTER(POINTER(win32more.Windows.Win32.Media.Audio.WAVEFORMATEX))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Initialize(self, pData: VoidPtr, DataByteSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Reset(self) -> Void: ...
    @commethod(8)
    def LockForProcess(self, InputLockedParameterCount: UInt32, pInputLockedParameters: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAPO_LOCKFORPROCESS_PARAMETERS), OutputLockedParameterCount: UInt32, pOutputLockedParameters: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAPO_LOCKFORPROCESS_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def UnlockForProcess(self) -> Void: ...
    @commethod(10)
    def Process(self, InputProcessParameterCount: UInt32, pInputProcessParameters: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAPO_PROCESS_BUFFER_PARAMETERS), OutputProcessParameterCount: UInt32, pOutputProcessParameters: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAPO_PROCESS_BUFFER_PARAMETERS), IsEnabled: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
    @commethod(11)
    def CalcInputFrames(self, OutputFrameCount: UInt32) -> UInt32: ...
    @commethod(12)
    def CalcOutputFrames(self, InputFrameCount: UInt32) -> UInt32: ...
class IXAPOHrtfParameters(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{15b3cd66-e9de-4464-b6e6-2bc3cf63d455}')
    @commethod(3)
    def SetSourcePosition(self, position: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.HrtfPosition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetSourceOrientation(self, orientation: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.HrtfOrientation)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetSourceGain(self, gain: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetEnvironment(self, environment: win32more.Windows.Win32.Media.Audio.XAudio2.HrtfEnvironment) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXAPOParameters(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{26d95c66-80f2-499a-ad54-5ae7f01c6d98}')
    @commethod(3)
    def SetParameters(self, pParameters: VoidPtr, ParameterByteSize: UInt32) -> Void: ...
    @commethod(4)
    def GetParameters(self, pParameters: VoidPtr, ParameterByteSize: UInt32) -> Void: ...
class IXAudio2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{2b02e3cf-2e0b-4ec3-be45-1b2a3fe7210d}')
    @commethod(3)
    def RegisterForCallbacks(self, pCallback: win32more.Windows.Win32.Media.Audio.XAudio2.IXAudio2EngineCallback) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def UnregisterForCallbacks(self, pCallback: win32more.Windows.Win32.Media.Audio.XAudio2.IXAudio2EngineCallback) -> Void: ...
    @commethod(5)
    def CreateSourceVoice(self, ppSourceVoice: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.IXAudio2SourceVoice), pSourceFormat: POINTER(win32more.Windows.Win32.Media.Audio.WAVEFORMATEX), Flags: UInt32, MaxFrequencyRatio: Single, pCallback: win32more.Windows.Win32.Media.Audio.XAudio2.IXAudio2VoiceCallback, pSendList: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_VOICE_SENDS), pEffectChain: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_EFFECT_CHAIN)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateSubmixVoice(self, ppSubmixVoice: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.IXAudio2SubmixVoice), InputChannels: UInt32, InputSampleRate: UInt32, Flags: UInt32, ProcessingStage: UInt32, pSendList: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_VOICE_SENDS), pEffectChain: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_EFFECT_CHAIN)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def CreateMasteringVoice(self, ppMasteringVoice: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.IXAudio2MasteringVoice), InputChannels: UInt32, InputSampleRate: UInt32, Flags: UInt32, szDeviceId: win32more.Windows.Win32.Foundation.PWSTR, pEffectChain: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_EFFECT_CHAIN), StreamCategory: win32more.Windows.Win32.Media.Audio.AUDIO_STREAM_CATEGORY) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def StartEngine(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def StopEngine(self) -> Void: ...
    @commethod(10)
    def CommitChanges(self, OperationSet: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetPerformanceData(self, pPerfData: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_PERFORMANCE_DATA)) -> Void: ...
    @commethod(12)
    def SetDebugConfiguration(self, pDebugConfiguration: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_DEBUG_CONFIGURATION), pReserved: VoidPtr) -> Void: ...
class IXAudio2EngineCallback(ComPtr):
    extends: None
    @commethod(0)
    def OnProcessingPassStart(self) -> Void: ...
    @commethod(1)
    def OnProcessingPassEnd(self) -> Void: ...
    @commethod(2)
    def OnCriticalError(self, Error: win32more.Windows.Win32.Foundation.HRESULT) -> Void: ...
class IXAudio2Extension(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{84ac29bb-d619-44d2-b197-e4acf7df3ed6}')
    @commethod(3)
    def GetProcessingQuantum(self, quantumNumerator: POINTER(UInt32), quantumDenominator: POINTER(UInt32)) -> Void: ...
    @commethod(4)
    def GetProcessor(self, processor: POINTER(UInt32)) -> Void: ...
class IXAudio2MasteringVoice(ComPtr):
    extends: win32more.Windows.Win32.Media.Audio.XAudio2.IXAudio2Voice
    @commethod(19)
    def GetChannelMask(self, pChannelmask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXAudio2SourceVoice(ComPtr):
    extends: win32more.Windows.Win32.Media.Audio.XAudio2.IXAudio2Voice
    @commethod(19)
    def Start(self, Flags: UInt32, OperationSet: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def Stop(self, Flags: UInt32, OperationSet: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def SubmitSourceBuffer(self, pBuffer: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_BUFFER), pBufferWMA: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_BUFFER_WMA)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def FlushSourceBuffers(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def Discontinuity(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def ExitLoop(self, OperationSet: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def GetState(self, pVoiceState: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_VOICE_STATE), Flags: UInt32) -> Void: ...
    @commethod(26)
    def SetFrequencyRatio(self, Ratio: Single, OperationSet: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetFrequencyRatio(self, pRatio: POINTER(Single)) -> Void: ...
    @commethod(28)
    def SetSourceSampleRate(self, NewSourceSampleRate: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXAudio2SubmixVoice(ComPtr):
    extends: win32more.Windows.Win32.Media.Audio.XAudio2.IXAudio2Voice
class IXAudio2Voice(ComPtr):
    extends: None
    @commethod(0)
    def GetVoiceDetails(self, pVoiceDetails: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_VOICE_DETAILS)) -> Void: ...
    @commethod(1)
    def SetOutputVoices(self, pSendList: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_VOICE_SENDS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(2)
    def SetEffectChain(self, pEffectChain: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_EFFECT_CHAIN)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(3)
    def EnableEffect(self, EffectIndex: UInt32, OperationSet: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def DisableEffect(self, EffectIndex: UInt32, OperationSet: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetEffectState(self, EffectIndex: UInt32, pEnabled: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> Void: ...
    @commethod(6)
    def SetEffectParameters(self, EffectIndex: UInt32, pParameters: VoidPtr, ParametersByteSize: UInt32, OperationSet: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetEffectParameters(self, EffectIndex: UInt32, pParameters: VoidPtr, ParametersByteSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetFilterParameters(self, pParameters: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_FILTER_PARAMETERS), OperationSet: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetFilterParameters(self, pParameters: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_FILTER_PARAMETERS)) -> Void: ...
    @commethod(10)
    def SetOutputFilterParameters(self, pDestinationVoice: win32more.Windows.Win32.Media.Audio.XAudio2.IXAudio2Voice, pParameters: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_FILTER_PARAMETERS), OperationSet: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetOutputFilterParameters(self, pDestinationVoice: win32more.Windows.Win32.Media.Audio.XAudio2.IXAudio2Voice, pParameters: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_FILTER_PARAMETERS)) -> Void: ...
    @commethod(12)
    def SetVolume(self, Volume: Single, OperationSet: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetVolume(self, pVolume: POINTER(Single)) -> Void: ...
    @commethod(14)
    def SetChannelVolumes(self, Channels: UInt32, pVolumes: POINTER(Single), OperationSet: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetChannelVolumes(self, Channels: UInt32, pVolumes: POINTER(Single)) -> Void: ...
    @commethod(16)
    def SetOutputMatrix(self, pDestinationVoice: win32more.Windows.Win32.Media.Audio.XAudio2.IXAudio2Voice, SourceChannels: UInt32, DestinationChannels: UInt32, pLevelMatrix: POINTER(Single), OperationSet: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetOutputMatrix(self, pDestinationVoice: win32more.Windows.Win32.Media.Audio.XAudio2.IXAudio2Voice, SourceChannels: UInt32, DestinationChannels: UInt32, pLevelMatrix: POINTER(Single)) -> Void: ...
    @commethod(18)
    def DestroyVoice(self) -> Void: ...
class IXAudio2VoiceCallback(ComPtr):
    extends: None
    @commethod(0)
    def OnVoiceProcessingPassStart(self, BytesRequired: UInt32) -> Void: ...
    @commethod(1)
    def OnVoiceProcessingPassEnd(self) -> Void: ...
    @commethod(2)
    def OnStreamEnd(self) -> Void: ...
    @commethod(3)
    def OnBufferStart(self, pBufferContext: VoidPtr) -> Void: ...
    @commethod(4)
    def OnBufferEnd(self, pBufferContext: VoidPtr) -> Void: ...
    @commethod(5)
    def OnLoopEnd(self, pBufferContext: VoidPtr) -> Void: ...
    @commethod(6)
    def OnVoiceError(self, pBufferContext: VoidPtr, Error: win32more.Windows.Win32.Foundation.HRESULT) -> Void: ...
XAPO_BUFFER_FLAGS = Int32
XAPO_BUFFER_SILENT: win32more.Windows.Win32.Media.Audio.XAudio2.XAPO_BUFFER_FLAGS = 0
XAPO_BUFFER_VALID: win32more.Windows.Win32.Media.Audio.XAudio2.XAPO_BUFFER_FLAGS = 1
class XAPO_LOCKFORPROCESS_PARAMETERS(Structure):
    pFormat: POINTER(win32more.Windows.Win32.Media.Audio.WAVEFORMATEX)
    MaxFrameCount: UInt32
    _pack_ = 1
class XAPO_PROCESS_BUFFER_PARAMETERS(Structure):
    pBuffer: VoidPtr
    BufferFlags: win32more.Windows.Win32.Media.Audio.XAudio2.XAPO_BUFFER_FLAGS
    ValidFrameCount: UInt32
    _pack_ = 1
class XAPO_REGISTRATION_PROPERTIES(Structure):
    clsid: Guid
    FriendlyName: Char * 256
    CopyrightInfo: Char * 256
    MajorVersion: UInt32
    MinorVersion: UInt32
    Flags: UInt32
    MinInputBufferCount: UInt32
    MaxInputBufferCount: UInt32
    MinOutputBufferCount: UInt32
    MaxOutputBufferCount: UInt32
    _pack_ = 1
class XAUDIO2FX_REVERB_I3DL2_PARAMETERS(Structure):
    WetDryMix: Single
    Room: Int32
    RoomHF: Int32
    RoomRolloffFactor: Single
    DecayTime: Single
    DecayHFRatio: Single
    Reflections: Int32
    ReflectionsDelay: Single
    Reverb: Int32
    ReverbDelay: Single
    Diffusion: Single
    Density: Single
    HFReference: Single
    _pack_ = 1
class XAUDIO2FX_REVERB_PARAMETERS(Structure):
    WetDryMix: Single
    ReflectionsDelay: UInt32
    ReverbDelay: Byte
    RearDelay: Byte
    SideDelay: Byte
    PositionLeft: Byte
    PositionRight: Byte
    PositionMatrixLeft: Byte
    PositionMatrixRight: Byte
    EarlyDiffusion: Byte
    LateDiffusion: Byte
    LowEQGain: Byte
    LowEQCutoff: Byte
    HighEQGain: Byte
    HighEQCutoff: Byte
    RoomFilterFreq: Single
    RoomFilterMain: Single
    RoomFilterHF: Single
    ReflectionsGain: Single
    ReverbGain: Single
    DecayTime: Single
    Density: Single
    RoomSize: Single
    DisableLateField: win32more.Windows.Win32.Foundation.BOOL
    _pack_ = 1
class XAUDIO2FX_VOLUMEMETER_LEVELS(Structure):
    pPeakLevels: POINTER(Single)
    pRMSLevels: POINTER(Single)
    ChannelCount: UInt32
    _pack_ = 1
class XAUDIO2_BUFFER(Structure):
    Flags: UInt32
    AudioBytes: UInt32
    pAudioData: POINTER(Byte)
    PlayBegin: UInt32
    PlayLength: UInt32
    LoopBegin: UInt32
    LoopLength: UInt32
    LoopCount: UInt32
    pContext: VoidPtr
    _pack_ = 1
class XAUDIO2_BUFFER_WMA(Structure):
    pDecodedPacketCumulativeBytes: POINTER(UInt32)
    PacketCount: UInt32
    _pack_ = 1
class XAUDIO2_DEBUG_CONFIGURATION(Structure):
    TraceMask: UInt32
    BreakMask: UInt32
    LogThreadID: win32more.Windows.Win32.Foundation.BOOL
    LogFileline: win32more.Windows.Win32.Foundation.BOOL
    LogFunctionName: win32more.Windows.Win32.Foundation.BOOL
    LogTiming: win32more.Windows.Win32.Foundation.BOOL
    _pack_ = 1
class XAUDIO2_EFFECT_CHAIN(Structure):
    EffectCount: UInt32
    pEffectDescriptors: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_EFFECT_DESCRIPTOR)
    _pack_ = 1
class XAUDIO2_EFFECT_DESCRIPTOR(Structure):
    pEffect: win32more.Windows.Win32.System.Com.IUnknown
    InitialState: win32more.Windows.Win32.Foundation.BOOL
    OutputChannels: UInt32
    _pack_ = 1
class XAUDIO2_FILTER_PARAMETERS(Structure):
    Type: win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_FILTER_TYPE
    Frequency: Single
    OneOverQ: Single
    _pack_ = 1
XAUDIO2_FILTER_TYPE = Int32
LowPassFilter: win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_FILTER_TYPE = 0
BandPassFilter: win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_FILTER_TYPE = 1
HighPassFilter: win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_FILTER_TYPE = 2
NotchFilter: win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_FILTER_TYPE = 3
LowPassOnePoleFilter: win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_FILTER_TYPE = 4
HighPassOnePoleFilter: win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_FILTER_TYPE = 5
class XAUDIO2_PERFORMANCE_DATA(Structure):
    AudioCyclesSinceLastQuery: UInt64
    TotalCyclesSinceLastQuery: UInt64
    MinimumCyclesPerQuantum: UInt32
    MaximumCyclesPerQuantum: UInt32
    MemoryUsageInBytes: UInt32
    CurrentLatencyInSamples: UInt32
    GlitchesSinceEngineStarted: UInt32
    ActiveSourceVoiceCount: UInt32
    TotalSourceVoiceCount: UInt32
    ActiveSubmixVoiceCount: UInt32
    ActiveResamplerCount: UInt32
    ActiveMatrixMixCount: UInt32
    ActiveXmaSourceVoices: UInt32
    ActiveXmaStreams: UInt32
    _pack_ = 1
class XAUDIO2_SEND_DESCRIPTOR(Structure):
    Flags: UInt32
    pOutputVoice: win32more.Windows.Win32.Media.Audio.XAudio2.IXAudio2Voice
    _pack_ = 1
class XAUDIO2_VOICE_DETAILS(Structure):
    CreationFlags: UInt32
    ActiveFlags: UInt32
    InputChannels: UInt32
    InputSampleRate: UInt32
    _pack_ = 1
class XAUDIO2_VOICE_SENDS(Structure):
    SendCount: UInt32
    pSends: POINTER(win32more.Windows.Win32.Media.Audio.XAudio2.XAUDIO2_SEND_DESCRIPTOR)
    _pack_ = 1
class XAUDIO2_VOICE_STATE(Structure):
    pCurrentBufferContext: VoidPtr
    BuffersQueued: UInt32
    SamplesPlayed: UInt64
    _pack_ = 1


make_ready(__name__)
